<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "slake";

    $theme_dir = get_template_directory_uri();

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'redux_demo/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    $sampleHTML = '';

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Theme Options', 'slake' ),
        'page_title'           => __( 'Theme Options', 'slake' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => false,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => 2,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf('<p>%s <strong>%s</strong></p>', esc_html( 'Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable:', 'buffet' ), $v );
    } else {
        $args['intro_text'] = sprintf('<p>%s</p>',  __( 'This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.', 'slake' ) );
    }

    // Add content after the form.
    $args['footer_text'] = sprintf('<p>%s</p>', __( 'This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.', 'slake' ) );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'slake' ),
            'content' => '<p>' . esc_html__( 'This is the tab content, HTML is allowed.', 'slake' ) . '</p>'
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'slake' ),
            'content' => '<p>' . esc_html__( 'This is the tab content, HTML is allowed.', 'slake' ) . '</p>'
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content =  '<p>' . esc_html__( 'This is the sidebar content, HTML is allowed.', 'slake' ) . '</p>';
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */


     Redux::setSection( $opt_name, array(
         'title'            => esc_html__( 'General Settings', 'slake' ),
         'id'               => 'general_settings',
         'class'            => 'option-page-layout',
         'customizer_width' => '450px',
         'fields'           => array(
            array(
                'id'       => 'preloader',
                'type'     => 'switch',
                'title'    => esc_html__( 'Preloader', 'slake' ),
                'subtitle' => esc_html__( 'Show or hide preloader', 'slake' ),
                'default'  => true
            ),
            array(
                'id'       => 'scrolltotop',
                'type'     => 'switch',
                'title'    => esc_html__( 'Enable scroll to top.', 'slake' ),
                'subtitle' => esc_html__( 'Show or hide scroll to top button.', 'slake' ),
                'default'  => true
            ),


         )
     ) );


     Redux::setSection( $opt_name, array(
         'title'            => esc_html__( 'Header', 'slake' ),
         'id'               => 'header_settings',
         'class'            => 'option-page-layout',
         'customizer_width' => '450px',
         'fields'           => array(
             array(
                 'id'       => 'header_variations',
                 'type'     => 'image_select',
                 'title'    => esc_html__( 'Header Variations', 'slake' ),
                 'subtitle'    => esc_html__( 'Select the header variations.', 'slake' ),
                 'options'  => array(
                    'style-1' => $theme_dir . '/assets/img/header-layouts/style-1.png',
                    'style-2' => $theme_dir . '/assets/img/header-layouts/style-2.png',
                ),
                 'default'     => 'style-1',
             ),

             array(
                 'id'       => 'enable_top_header',
                 'type'     => 'switch',
                 'title'    => esc_html__( 'Enable Top Hader', 'slake' ),
                 'subtitle'    => esc_html__( 'Show/hide
                 ader.', 'slake' ),
                 'default'     => true,
             ),
             array(
                 'id'       => 'top_header_left_shortcodes',
                 'type'     => 'textarea',
                 'title'    => esc_html__( 'Header Top Left Shortcodes', 'slake' ),
                 'subtitle'    => esc_html__( 'Put your shortcodes that will show in top header part on left side.', 'slake' ),
                 'required'   => array( 'enable_top_header', 'equals', true ),
                 'default'     => '[slake_info_icon link="tel:+8801711991383" icon="ti-headphone-alt" info="+8801711991383"]',
             ),

         )
     ) );




    Redux::setSection( $opt_name, array(
        'title'            => __( 'Logo', 'slake' ),
        'id'               => 'logo_settings',
        'customizer_width' => '450px',
        'fields'           => array(
            array(
                'id'       => 'logo',
                'type'     => 'media',
                'title'    => esc_html__( 'Logo', 'slake' ),
                'subtitle' => esc_html__( 'Choose the site logo', 'slake' ),
                'default'  => array(
                    'url'=>  get_template_directory_uri() . '/assets/img/logo/logo.png'
                ),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => __( 'Layout', 'slake' ),
        'id'               => 'layout_settings',
        'customizer_width' => '450px',
        'fields'           => array(
            array(
                'id'       => 'use_box_mode',
                'type'     => 'switch',
                'title'    => esc_html__( 'Use Box Mode?', 'slake' ),
                'description' => esc_html__('Turn this on to use box mode on your site.', 'slake'),
            ),

            array(
                'id'       => 'box_mode_background',
                'type'     => 'background',
                'title'    => __('Body Background', 'slake'),
                'subtitle' => __('Body background with image, color, etc.', 'slake'),
                'required'   => array( 'use_box_mode', 'equals', true ),
                'output'    => array('body.layout-boxed'),
            )
        )
    ) );


    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Accent Colors', 'slake' ),
        'id'               => 'accent_colors',
        'desc'             => esc_html__( 'Select the accent color for your site.', 'slake' ),
        'customizer_width' => '400px',
        'icon'             => 'el el-home',
        'fields'           => array(
            array(
                'id'       => 'accent_color_options',
                'type'     => 'select',
                'title'    => esc_html__( 'Choose accent color options', 'slake' ),
                'description' => esc_html__('Wish to use any custom header template on 404 errors not found page?', 'slake'),
                'options'          => array(
                    'default-accent-color' => 'Default Accent Color',
                    'custom-accent-color' => 'Custom Accent Color',
                ),
                'default' => 'default-accent-color'
            ),
            array(
                'id'       => 'default_accent_color',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Choose Default Color Scheme', 'slake' ),
                'subtitle'    => esc_html__( 'Choose any predefined color settings from here.', 'slake' ),
                'options'          => array(
                    'color-red' => get_template_directory_uri() .'/assets/img/color-variant/color-1.png"',
                    'color-green' => get_template_directory_uri() .'/assets/img/color-variant/color-2.png"',
                    'color-blue-2' => get_template_directory_uri() .'/assets/img/color-variant/color-3.png"',
                    'color-blue' => get_template_directory_uri() .'/assets/img/color-variant/color-4.png"',
                    'color-violet' => get_template_directory_uri() .'/assets/img/color-variant/color-5.png"',
                    'color-orange' => get_template_directory_uri() .'/assets/img/color-variant/color-6.png"',
                    'color-turquoise' => get_template_directory_uri() .'/assets/img/color-variant/color-7.png"',
                    'color-pink' => get_template_directory_uri() .'/assets/img/color-variant/color-8.png"',
                    'color-cornflower-blue' => get_template_directory_uri() .'/assets/img/color-variant/color-9.png"',
                ),
                'required'   => array( 'accent_color_options', 'equals', 'default-accent-color' ),
            ),
            array(
                'id'       => 'custom_accent_color',
                'type'     => 'color',
                'title'    => __('Accent Color', 'slake'),
                'subtitle' => __('Pick a color for the theme.', 'slake'),
                'validate' => 'color',
                'required'   => array( 'accent_color_options', 'equals', 'custom-accent-color' ),
                'default' => '#4777f4',
            )
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => __( 'Breadcrumbs', 'slake' ),
        'id'               => 'breadcrumb_settings',
        'customizer_width' => '450px',
        'fields'           => array(
            array(
                'id'       => 'breadcrumb_on',
                'type'     => 'switch',
                'title'    => esc_html__( 'Breadcrumb On/Off ', 'slake' ),
                'subtitle'    => esc_html__( 'Show/hide the breadcrumb.', 'slake' ),
                'desc'      => esc_html__( 'This setting can be override by page breatdcrumb settings.', 'slake' ),
                'default'     => true,
            ),
            array(
                'id'       => 'breadcrumb_sep',
                'type'     => 'text',
                'title'    => __( 'Breadcrumb Seperator ', 'slake' ),
                'default'     => '-',
                'required'   => array( 'breadcrumb_on', 'equals', true ),
            ),
            array(
                'id'        => 'breadcrumb_background',
                'type'      => 'background',
                'output'    => array('.blog-full-page-area.breadcrumb-area'),
                'title'     => esc_html__( 'Breadcrumb Background', 'slake' ),
                'subtitle'  => esc_html__( 'Customize your breadcrumb background area.', 'slake' ),
                'desc'      => esc_html__( 'This setting can be override by page breatdcrumb settings.', 'slake' ),
                'required'   => array( 'breadcrumb_on', 'equals', true ),
                'default'   => array(
                    'background-color' => '#EFEFEE',
                )
            ),
            array(
                'id'                => 'breadcrumb_spacing',
                'type'              => 'spacing',
                'output'            => array('.blog-full-page-area.breadcrumb-area'),
                'mode'              => 'padding',
                'units'             => array('em', 'px'),
                'units_extended'    => 'false',
                'title'             => esc_html__('Breadcrumb Area Padding', 'slake'),
                'subtitle'          => esc_html__('Please specify breadcrumb area padding.', 'slake'),
                'required'          => array( 'breadcrumb_on', 'equals', true ),
            ),
            array(
                'id'          => 'breadcrumb_typography',
                'type'        => 'typography',
                'title'       => esc_html__('Breadcrumb Typography', 'slake'),
                'google'      => true,
                'font-backup' => true,
                'letter-spacing' => true,
                'output'      => array('.breadcrumb-area .breadcrumb_title'),
                'units'       =>'px',
                'subtitle'    => esc_html__('Set typography for breadcrumb title', 'slake'),
                'required'   => array( 'breadcrumb_on', 'equals', true ),
            ),
        )
    ) );




    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Typography', 'slake' ),
        'id'               => 'body_typography',
        'customizer_width' => '450px',
        'fields'           => array(
             array(
                 'id'       => 'bdy_typography',
                'type'        => 'typography',
                'title'       => esc_html__('Body Typography', 'slake'),
                'google'      => true,
                'font-backup' => true,
                'line-height' => true,
                'letter-spacing' => true,
                'output'      => array('body'),
                'units'       =>'px',
                'subtitle'    => esc_html__('Set typography for body', 'slake'),

            ),
             array(
                 'id'       => 'h1_typography',
                'type'        => 'typography',
                'title'       => esc_html__('H1 Typography', 'slake'),
                'google'      => true,
                'font-backup' => true,
                'line-height' => true,
                'letter-spacing' => true,
                'output'      => array('h1, .h1, body h1, body .h1'),
                'units'       =>'px',
                'subtitle'    => esc_html__('Set typography for header h1', 'slake'),

            ),
             array(
                 'id'       => 'h2_typography',
                'type'        => 'typography',
                'title'       => esc_html__('H2 Typography', 'slake'),
                'google'      => true,
                'font-backup' => true,
                'line-height' => true,
                'letter-spacing' => true,
                'output'      => array('h2, .h2, body h2, body .h2'),
                'units'       =>'px',
                'subtitle'    => esc_html__('Set typography for header h2', 'slake'),

            ),
             array(
                 'id'       => 'h3_typography',
                'type'        => 'typography',
                'title'       => esc_html__('H3 Typography', 'slake'),
                'google'      => true,
                'font-backup' => true,
                'line-height' => true,
                'letter-spacing' => true,
                'output'      => array('h3, .h3, body h3, body .h3'),
                'units'       =>'px',
                'subtitle'    => esc_html__('Set typography for header h3', 'slake'),

            ),
             array(
                 'id'       => 'h4_typography',
                'type'        => 'typography',
                'title'       => esc_html__('H4 Typography', 'slake'),
                'google'      => true,
                'font-backup' => true,
                'line-height' => true,
                'letter-spacing' => true,
                'output'      => array('h4, .h4, body h4, body .h4'),
                'units'       =>'px',
                'subtitle'    => esc_html__('Set typography for header h4', 'slake'),

            ),
             array(
                 'id'       => 'h5_typography',
                'type'        => 'typography',
                'title'       => esc_html__('H5 Typography', 'slake'),
                'google'      => true,
                'line-height' => true,
                'font-backup' => true,
                'letter-spacing' => true,
                'output'      => array('h5, .h5, body h5, body .h5'),
                'units'       =>'px',
                'subtitle'    => esc_html__('Set typography for header h5', 'slake'),

            ),
             array(
                 'id'       => 'h6_typography',
                'type'        => 'typography',
                'title'       => esc_html__('H6 Typography', 'slake'),
                'google'      => true,
                'font-backup' => true,
                'line-height' => true,
                'letter-spacing' => true,
                'output'      => array('h6, .h6, body h6, body .h6'),
                'units'       =>'px',
                'subtitle'    => esc_html__('Set typography for header h6', 'slake'),

            )
        )
    ) );





    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Page Settings', 'slake' ),
        'id'               => 'page_setings',
        'desc'             => esc_html__( 'Buffet blog settings!', 'slake' ),
        'customizer_width' => '400px',
        'icon'             => 'el el-home',
    ) );




    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Blog Page', 'slake' ),
        'id'               => 'blog_settings',
        'customizer_width' => '450px',
        'subsection'       => true,
        'fields'           => array(
            array(
                'id'       => 'bp_title',
                'type'     => 'text',
                'title'    => esc_html__( 'Blog Page Title', 'slake' ),
                'subtitle'    => esc_html__( 'Give any breadcrumb page title for the blog page.', 'slake' ),
                'default'     => esc_html__('Latest Blog', 'slake'),
            ),
            array(
                'id'       => 'blog_layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Blog Layout', 'slake' ),
                'subtitle' => esc_html__( 'Choose the layout you want in blog pages', 'slake' ),
                'options'          => array(
                    'fullpage' => get_template_directory_uri() .'/assets/img/layouts/fullpage.png"',
                    'left-sidebar' => get_template_directory_uri() .'/assets/img/layouts/left-sidebar.jpg"',
                    'right-sidebar' => get_template_directory_uri() .'/assets/img/layouts/right-sidebar.jpg"',
                ),
                'default'  => 'right-sidebar',
            ),
            array(
                'id'       => 'blog_grid',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Blog Grid', 'slake' ),
                'subtitle' => esc_html__( 'Choose the number of column you want in blog pages', 'slake' ),
                'options'          => array(
                    'one-column' => get_template_directory_uri() .'/assets/img/layouts/1-col.png"',
                    'two-column' => get_template_directory_uri() .'/assets/img/layouts/2-col.png"',
                    'three-column' => get_template_directory_uri() .'/assets/img/layouts/3-col.png"',
                ),
                'default'  => 'one-column',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Shop Page', 'slake' ),
        'id'               => 'shop_settings',
        'customizer_width' => '450px',
        'subsection'       => true,
        'fields'           => array(
            array(
                'id'       => 'shop_title',
                'type'     => 'text',
                'title'    => esc_html__( 'Shop Page Title', 'slake' ),
                'subtitle'    => esc_html__( 'Give any breadcrumb page title for the shop page.', 'slake' ),
                'default'     => esc_html__('Our Shop', 'slake'),
            ),
            array(
                'id'       => 'shop_layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Shop Layout', 'slake' ),
                'subtitle' => esc_html__( 'Choose the layout you want in shop pages', 'slake' ),
                'options'          => array(
                    'fullpage' => get_template_directory_uri() .'/assets/img/layouts/fullpage.png"',
                    'left-sidebar' => get_template_directory_uri() .'/assets/img/layouts/left-sidebar.jpg"',
                    'right-sidebar' => get_template_directory_uri() .'/assets/img/layouts/right-sidebar.jpg"',
                ),
                'default'  => 'right-sidebar',
            ),
        )
    ) );


    Redux::setSection( $opt_name, array(
        'title'            => __( 'Single Page', 'slake' ),
        'id'               => 'single_page_settings',
        'customizer_width' => '450px',
        'subsection'       => true,
        'fields'           => array(
            array(
                'id'       => 'sp_title',
                'type'     => 'text',
                'title'    => esc_html__( 'Single Page Title', 'slake' ),
                'subtitle'    => esc_html__( 'Give any breadcrumb page title for the single article page.', 'slake' ),
                'default'     => 'Blog Details',
            ),
            array(
                'id'       => 'single_page_layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Single Page Layout', 'slake' ),
                'subtitle' => esc_html__( 'Choose the layout you want in single pages', 'slake' ),
                'options'          => array(
                    'fullpage' => get_template_directory_uri() .'/assets/img/layouts/fullpage.png"',
                    'left-sidebar' => get_template_directory_uri() .'/assets/img/layouts/left-sidebar.jpg"',
                    'right-sidebar' => get_template_directory_uri() .'/assets/img/layouts/right-sidebar.jpg"',
                ),
                'default'  => 'right-sidebar',
            ),
        )
    ) );


    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Google Apps', 'slake' ),
        'id'               => 'google_apps',
        'desc'             => esc_html__( 'Google Apps', 'slake' ),
        'customizer_width' => '400px',
        'icon'             => 'el el-home'
    ) );


    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Google Api', 'slake' ),
        'id'               => 'google_api',
        'subsection'       => true,
        'customizer_width' => '450px',
        'fields'           => array(
            array(
                'id'       => 'google-map-api-key',
                'type'     => 'text',
                'title'    => esc_html__( 'Google JavaScript Map API key', 'slake' ),
                'description' => esc_html__('Add your google javascript api key. Read the theme documentation to learn more about google javascript api key.', 'slake'),
            ),
        )
    ) );



     Redux::setSection( $opt_name, array(
         'title'            => esc_html__( 'Coming Soon', 'slake' ),
         'id'               => 'coming_soon_settings',
         'class'            => 'option-page-layout',
         'customizer_width' => '450px',
         'fields'           => array(
            array(
                'id'       => 'coming_soon_mode',
                'type'     => 'switch',
                'title'    => esc_html__( 'Coming Soon Mode', 'slake' ),
                'subtitle' => esc_html__( 'Enable or Disable Coming Soon Mode', 'slake' ),
                'default'  => false
            ),
            array(
                'id'    => 'coming_soon_page',
                'type'  => 'select',
                'title' => __( 'Select Coming Soon Page', 'slake' ),
                'description' => __( 'Select the coming soon template.', 'slake' ),
                'data'  => 'posts',
                'args'  => array(
                    'post_type'      => 'page',
                    'posts_per_page' => -1,
                    'orderby'        => 'title',
                    'order'          => 'ASC',
                ),
                'required'   => array( 'coming_soon_mode', 'equals', true ),

            ),
         )
     ) );



    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Footer', 'slake' ),
        'id'               => 'footer',
        'desc'             => esc_html__( 'Buffet footer settings!', 'slake' ),
        'customizer_width' => '400px',
        'icon'             => 'el el-home',
        'fields'           => array(

            array(
                'id'       => 'use_custom_footer_template',
                'type'     => 'switch',
                'title'    => esc_html__( 'Use Custom Footer Template', 'slake' ),
                'description' => esc_html__('Wish to use any custom footer template?', 'slake'),
            ),
            array(
                'id'    => 'footer_section',
                'type'  => 'select',
                'title' => __( 'Select Footer Template', 'slake' ),
                'description' => __( 'You can build your footer with King Composer Sections manager and select that template section here so that your selected footer template will show all over the site.', 'slake' ),
                'data'  => 'posts',
                'args'  => array(
                    'post_type'      => 'elementor_library',
                    'posts_per_page' => -1,
                    'orderby'        => 'title',
                    'order'          => 'ASC',
                ),
                'required'   => array( 'use_custom_footer_template', 'equals', true ),
            ),


        )
    ) );




    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */


    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
        }
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $field['msg']    = 'your custom error message';
                $return['error'] = $field;
            }

            if ( $warning == true ) {
                $field['msg']      = 'your custom warning message';
                $return['warning'] = $field;
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => __( 'Section via hook', 'slake' ),
                'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'slake' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }
