<?php

// File Security Check
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


if( ! function_exists( 'slake_theme_setup' ) ) :

	function slake_theme_setup() {

		global $slake;

		// Load the theme text domain
		load_theme_textdomain( 'slake', get_template_directory() . '/lang' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Add title tag
		add_theme_support( 'title-tag' );

		// Adding WooCommerce Support
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );

		// Add post-thumbnails
		add_theme_support( 'post-thumbnails' );

		add_theme_support( 'post-formats', array(
			'quote',
			'video',
			'image',
			'audio',
		) );

		// Add theme support for gutenberg
		add_theme_support(
		    'gutenberg',
		    array( 'wide-images' => true )
		);

		add_theme_support( 'align-wide' );

	    add_image_size( 'slake-post-img-small', 370, 235, true );
	    add_image_size( 'slake-post-img-medium', 555, 350, true );
	    add_image_size( 'slake-post-img-large', 1140, 600, true );
	    add_image_size( 'slake-service-img-large', 1140, 600, true );
	    add_image_size( 'slake-blog-thumb', 80, 70, true );

	    // Set content width
	    if ( ! isset( $content_width ) ) {
			$content_width = 600;
		}

		$defaults = array(
			'default-color'          => '#f8f8f8',
		);
		add_theme_support( 'custom-background', $defaults );

		if( function_exists('register_nav_menus') ) {
			register_nav_menus( array(
				'main-menu' => esc_html__('Main Menu', 'slake'),
				'top-menu' => esc_html__('Top bar Menu', 'slake'),
			) );
		}


		if( isset( $slake['mobile_menu'] ) && $slake['mobile_menu'] == true ) {
			register_nav_menus( array(
				'mobile-menu' => esc_html__('Mobile Menu', 'slake'),
			) );
		}

	}

endif;

add_action( 'after_setup_theme', 'slake_theme_setup' );


function slake_dd($var){
	echo '<pre>';
	print_r( $var );
	echo '</pre>';
}


/**
 * Detect Homepage
 *
 * @return boolean value
 */
function slake_detect_homepage() {
    // If front page is set to display a static page, get the URL of the posts page.
    $homepage_id = get_option( 'page_on_front' );

    // current page id
    $current_page_id = ( is_page( get_the_ID() ) ) ? get_the_ID() : '';

    if( $homepage_id == $current_page_id ) {
        return true;
    } else {
        return false;
    }

}




/**
 *
 * Scorn Hide Footer Top
 *
 */

function slake_hide_footer_top() {

	global $slake;

	$output = 'show';

	if ( isset( $slake['footer_top_switch'] ) ) {

		if( $slake['footer_top_switch'] == true ) {

			$output = 'show';

		} else {

			$output = 'hide';

		}

	}

	if( function_exists( 'get_field') ) {

		if( get_field( 'hide_footer_top' ) ) {

			$output = 'hide';

		}

	}

	return $output;

}


/**
 *
 * Scorn Hide Footer Top
 *
 */

function slake_hide_footer_btm() {

	global $slake;

	$output = 'show';

	if ( isset( $slake['footer_bottom_switch'] ) ) {

		if( $slake['footer_bottom_switch'] == true ) {

			$output = 'show';

		} else {

			$output = 'hide';

		}

	}

	if( function_exists( 'get_field') ) {

		if( get_field( 'hide_footer_bottom' ) ) {

			$output = 'hide';

		}

	}

	return $output;

}



add_filter( 'template_include', 'slake_coming_soon', 99 );

function slake_coming_soon( $template ) {

	global $slake;

	if( isset( $slake['coming_soon_mode'] ) ) {
		if( $slake['coming_soon_mode'] == true ) {

			if( current_user_can('manage_options') ) {
				return $template;

			} else {
				$new_template = locate_template( array( 'templates/coming-soon.php' ) );
				if ( !empty( $new_template ) ) {
					return $new_template;
				}
			}
		}
	}

	return $template;

}

/**
 *
 * The posts loop pagination
 *
 */
function slake_page_posts_loop( $template )
{
    if( have_posts() ) :

        while( have_posts() ) : the_post();

            get_template_part('templates/content', $template );

        endwhile;

    else:
        get_template_part('templates/no-post');
    endif;
}


/**
 * Menu fallback. Link to the menu editor if that is useful.
 *
 * @param  array $args
 * @return string
 */
function slake_link_to_menu_editor( $args )
{
    if ( ! current_user_can( 'manage_options' ) )
    {
        return;
    }

    // see wp-includes/nav-menu-template.php for available arguments
    extract( $args );

    $link = $link_before
        . '<a href="' . esc_url( admin_url( 'nav-menus.php' ) ) . '">' . esc_attr( $before ) . esc_attr__('Create a menu', 'slake') . esc_attr($after) . '</a>'
        . $link_after;

    // We have a list
    if ( FALSE !== stripos( $items_wrap, '<ul' )
        or FALSE !== stripos( $items_wrap, '<ol' )
    )
    {
        $link = "<li>" . $link ."</li>";
    }

    $output = sprintf( $items_wrap, $menu_id, $menu_class, $link );
    if ( ! empty ( $container ) )
    {
        $output  = "<". esc_attr($container) ." class='". esc_attr($container_class) ."' id='". esc_attr($container_id) ."'>$output</". esc_attr($container) .">";
    }

    if ( $echo )
    {
        echo  $output;
    }

    return $output;
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'slake_loop_columns');

if (!function_exists('slake_loop_columns')) {
	function slake_loop_columns() {
		return 3; // 3 products per row
	}
}


/**
 *
 * By adding filter to loop_shop_per_page
 *
 */
add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 9;' ), 20 );


/**
 *
 * WordPress link pages
 *
 */
function slake_wp_link_pages() {

	wp_link_pages( array(
		'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'slake' ) . '</span>',
		'after'       => '</div>',
		'link_before' => '<span>',
		'link_after'  => '</span>',
	) );

}


function slake_get_pulled_sidebar($pull_class) {

	echo '<aside class="col-md-4 '. $pull_class .' widget_col">';

				if( is_active_sidebar('slake_sidebar') ) :
					dynamic_sidebar( 'slake_sidebar' );
				endif;

	echo '</aside>';
}

/**
 *
 * Add classes to post class by filting
 * @return $classes
 */

add_filter('post_class', 'slake_post_class');

function slake_post_class( $classes ) {

	global $slake;
	$classes[] = 'single-blog-box';

	if( is_single() ) {
		$classes[] = 'sp-blog-box';
	}

	if( isset($slake['blog_grid']))
		if( ! is_single() )
			$classes[] = $slake['blog_grid'];

	return $classes;
}



/**
 *
 * Registering Google Fonts
 *
 */


 function slake_google_fonts_url() {

    $font_url = '';

    if ( 'off' !== _x( 'on', 'Google font: on or off', 'slake' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Montserrat:300,300i,400,400i,500,500i,600,600i,700,700i,800,800i&subset=latin,latin-ext' ), "//fonts.googleapis.com/css" );
    }

    return $font_url;

}



/**
 *
 * Enqueuing Google Maps Script with  API key
 *
 */
function slake_google_maps_js_script() {

	global $slake;

	if( isset( $slake['google-map-api-key'] ) ) {

		$api_key = $slake['google-map-api-key'];
		wp_enqueue_script( 'google-map', 'https://maps.googleapis.com/maps/api/js?key=' . $api_key, array('jquery'), null, true );

	}
}


/**
 * Registers an editor stylesheet for the theme.
 */
function slake_theme_add_editor_styles() {
    add_editor_style( 'custom-editor-style.css' );
}
add_action( 'admin_init', 'slake_theme_add_editor_styles' );


/**
 *
 * Building Comments Lists
 *
 */
function slake_comments_list( $comment, $args, $depth ) {

	    $GLOBALS['comment'] = $comment;
	    switch( $comment->comment_type ) :
	        case 'tracback' :
	        case 'pingback' : ?>

	        <li <?php esc_attr( comment_class() ); ?> id="comment-<?php esc_attr( comment_ID() ); ?>">
			<p><span class="title"><?php esc_html_e( 'Pingback:', 'slake' ); ?></span> <?php esc_url( comment_author_link() ); ?> <?php esc_url ( edit_comment_link( esc_html__( '(Edit)', 'slake' ), '<span class="edit-link">', '</span>' ) ); ?></p>

	        <?php break;
	        default : ?>
			<li <?php esc_attr( comment_class() ); ?>  id="comment-<?php esc_attr(comment_ID() ); ?>">
				<div class="the-comment">
					<div class="comment-author">
						<span class="author__avatar">
							<?php echo get_avatar( $comment, 50 ); ?>
						</span>
						<div class="author-name">
							<strong><?php esc_html( comment_author() ); ?></strong>
							<span class="meta"><?php echo esc_html( the_time( get_option('date_format') ) );?> <?php  esc_html( comment_time() ); ?></span>
						</div>

					</div>
					<div class="comment-text">
						<?php
							if( $comment->comment_approved  == 0 ) {
								esc_html_e('Your comment is awating for moderation.', 'slake');
							} else {
								comment_text();
							}
						?>
					</div>
					<?php
						if( get_edit_comment_link() ) :
							esc_url( edit_comment_link( esc_html__('Edit', 'slake') ) );
						endif;
					?>

					<?php
						comment_reply_link( array_merge( $args, array(
							'reply_text' =>  esc_html__('Reply', 'slake'),
							'after' => ' <span> </span>',
							'depth' => $depth,
							'max_depth' => $args['max_depth']
						) ) );
					?>
				</div>
			</li>

	        <?php // End the default styling of comment
	        break;
	    endswitch;
}



function slake_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];

	unset( $fields['comment'] );

	$fields['comment'] = $comment_field;

	return $fields;
}

add_filter( 'comment_form_fields', 'slake_move_comment_field_to_bottom' );



function slake_custom_comment_form_fields() {
	$commenter = wp_get_current_commenter();
	$req = get_option('required_name_email');
	$aria_req = ($req ? " aria-required='true'" : ' ');

	$yourNamePlaceholder  = $aria_req ? esc_attr__('Name *', 'slake') : esc_attr__('Name ', 'slake');
	$yourEmailPlaceholder = $aria_req ? esc_attr__('Email *', 'slake') : esc_attr__('Email ', 'slake');
	$yourWebsitePlaceholder = $aria_req ? esc_attr__('Website *', 'slake') : esc_attr__('Website ', 'slake');

	$fields = array(
		'author' => '<div class="row"><div class="col-md-6"><div class="form-group">
					<label for="author">'. $yourNamePlaceholder .'</label>
					<input
						type="text"
						id="author"
						name="author"
						value="'. esc_attr( $commenter['comment_author'] ) .'"
						'. $aria_req .'
					></div></div>',

		'email' => '<div class="col-md-6"><div class="form-group">
					<label for="email">'. $yourEmailPlaceholder .'</label>
					<input
						type="email"
						id="email"
						name="email"
						value="'. esc_attr( $commenter['comment_author_email'] ) .'"
						'. $aria_req .'
					></div></div></div>',



	);

	return $fields;
}

add_filter('comment_form_default_fields', 'slake_custom_comment_form_fields');

/**
 *
 * Shape Tag Cloud font size
 *
 */
function slake_tag_cloud_widget($args) {
    $args['largest'] = 15; //largest tag
    $args['smallest'] = 15; //smallest tag
    $args['unit'] = 'px'; //tag font unit
    return $args;
}
add_filter( 'widget_tag_cloud_args', 'slake_tag_cloud_widget' );



/**
 * Get blog posts page URL.
 *
 * @return string The blog posts page URL.
 */
function slake_get_blog_posts_page_url() {
	// If front page is set to display a static page, get the URL of the posts page.
	if ( 'page' === get_option( 'show_on_front' ) ) {
		return esc_url(get_permalink( get_option( 'page_for_posts' ) ));
	}
	// The front page IS the posts page. Get its URL.
	return esc_url(get_home_url('/'));
}




// Apply filter
add_filter('body_class', 'slake_set_body_class');

function slake_set_body_class($classes) {

	global $slake;

	if( isset( $slake['use_box_mode'] ) && $slake['use_box_mode'] == true ) {
		$classes[] = 'layout-boxed';
	}


	if( isset( $slake['accent_color_options'] ) && $slake['accent_color_options'] == 'default-accent-color' ) {
		if( isset( $slake['default_accent_color'] ) ) {
			$classes[] = $slake['default_accent_color'];
		}
	}

	// Getting the page header style value
	$page_header_style = get_post_meta( get_the_ID(), 'header_variations', true);

	// Initialize the value for header styles
	$header_style_class = '';


	// Get the header variations value from Theme Options
	// priority level 2
	if( isset( $slake['header_variations'] ) ) {
		$header_style_class = 'header-' . $slake['header_variations'];
	}

	// Get the header variations value from Page header variation style
	// priority level 1
	if( $page_header_style && $page_header_style !== 'choose-style' ) {
		$header_style_class = 'header-' . $page_header_style;
	}

	// Check if there has values for header varitions
	// Add the class to body class
	if( ! empty( $header_style_class ) ) {
		$classes[] = $header_style_class;
	}



	// Check the shop layout

	if( function_exists('is_shop') ) {
		if( isset( $slake['shop_layout'] ) ) {
			$classes[] = 'shop-layout-' . $slake['shop_layout'];
		}
	}

	// Check if there has preloader enabled
	if( isset( $slake['preloader'] ) && $slake['preloader'] == true ) {
		$classes[] = 'preloader-on';
	}

	// Check if there has google map api enabled
	if( isset( $slake['google-map-api-key'] ) && $slake['google-map-api-key'] == true ) {
		$classes[] = 'has-google-map-key';
	}

	return $classes;
}


/**
 *
 * WHMCS Bridge Page URL
 *
 */
function slake_whmcs_bridge_url() {

	if( function_exists( 'cc_whmcs_bridge_home' ) ) {
		return cc_whmcs_bridge_home($home,$pid);
	} else {
		return home_url('/') . 'whmcs-bridge';
	}
}

/**
 * Set header class dynamically
 *
 */
function slake_set_header_class() {

	// Globalizing theme options variables
	global $slake;

    // Get the homepage ID
    $homepage_id = get_option( 'page_on_front' );

    // current page id
    $current_page_id = ( is_page( get_the_ID() ) ) ? get_the_ID() : '';



    $output_class = array();
    $output_class[] = 'header-area';



    //
    // If get_field function is exsits
    // This functions active when ACF is active
    //
    if( function_exists('get_field') ) {

    	/*----------  Header Positions for specific page  ----------*/
    	if( get_field('header_color_scheme') ) {

		    if( ($key = array_search($slake['header_layout'], $output_class)) !== false) {
		        unset($output_class[$key]);
		    }


			$output_class[] = get_field('header_color_scheme');


    	}


    }

    return $output_class;

}
/**
 * Set footer class dynamically
 *
 */
function slake_set_sidemenu_clas() {

	// Globalizing theme options variables
	global $slake;


    $output_class = array();
    $output_class[] = 'mainmenu-expand';

	$header_layout = ( isset( $slake['header_layout'] ) ) ?  $slake['header_layout'] : 'header_white';


    //
    // If get_field function is exsits
    // This functions active when ACF is active
    //
    if( function_exists('get_field') ) {

    	/*----------  Header Positions for specific page  ----------*/
    	if( get_field('header_color_scheme') ) {

		    if( ($key = array_search($slake['header_layout'], $output_class)) !== false) {
		        unset($output_class[$key]);
		    }

			$output_class[] = get_field('header_color_scheme');


    	}


    }

    return $output_class;

}


/**
 * Set footer class dynamically
 *
 */
function slake_set_footer_class() {

	// Globalizing theme options variables
	global $slake;


    $output_class = array();
    $output_class[] = 'footer-area';



    //
    // If get_field function is exsits
    // This functions active when ACF is active
    //
    if( function_exists('get_field') ) {

    	/*----------  Header Positions for specific page  ----------*/
    	if( get_field('footer_color_scheme') ) {

		    if( ($key = array_search($slake['footer_color_schema'], $output_class)) !== false) {
		        unset($output_class[$key]);
		    }

			$output_class[] = get_field('footer_color_scheme');

    	}


    }

    return $output_class;

}




//
// Get the site logo for Bufet
//
function slake_get_site_logo() {

    global $slake;

    $logo = '';
    $logo_url = '';

    $custom_logo = get_post_meta( get_the_ID(), 'use_custom_logo', true );
    $page_logo = get_post_meta( get_the_ID(), 'select_logo', true );

    if( $custom_logo ) {
		$img_url = wp_get_attachment_image_src( $page_logo );
        $logo_url = esc_url( $img_url[0] );
    } else if( isset( $slake['logo'] ) ) {
        $logo_url = esc_url( $slake['logo']['url'] );
    } else {
        $logo_url = get_template_directory_uri() .'/assets/img/logo/logo.png';
    }


    $logo .= '<img src="'. $logo_url .'" alt="'. get_bloginfo('title') .'">';

    return $logo;
}



function slake_footer_settings() {

	$slake = get_option('slake');


	if( isset( $slake['use_custom_footer_template'] ) ) {
		if( $slake['use_custom_footer_template'] == true ) {
			$post_id = $slake['footer_section'];

			// Query for blog posts
			$args = array(
				'post_type' => 'elementor_library',
				'posts_per_page'   => 1,
				'p' => $post_id
			);

			$posts = new WP_Query( $args );

			if( $posts->have_posts() ) :
				while( $posts->have_posts() ) :
					$posts->the_post();

						the_content();

				endwhile;
			endif;

		}

	} else {

		echo '<section class="footer-area">
	          <div class="container">
	            <div class="row">';

					if( is_active_sidebar('footer_widget') ) {
						dynamic_sidebar('footer_widget');
					}

	    echo   '</div>
	          </div>
	        </section>';
	}

}


function slake_header_classes() {
	global $post, $slake;

	$class_attr_start = 'class="';

	$output_class = array('header-top', 'headroom');
	$output_class_str = '';

	if ( $post ) {

		$use_custom_header = get_post_meta( $post->ID, 'use_custom_header', true);
		$choose_header_color_style = get_post_meta( $post->ID, 'choose_header_color_style', true);

		if( $use_custom_header == true ) {
			$output_class[] = $choose_header_color_style;
		} else {
			if( isset( $slake['menu_scheme']  ) ) {
				$output_class[] = $slake['menu_scheme'];
			}
		}
	}


	$output_class_str = implode(' ', $output_class);

	$class_attr_end = '"';


	return $class_attr_start . $output_class_str . $class_attr_end;

}


/**
 *
 * One click demo Installation for Slake theme
 *
 */

function slake_import_files() {
	return array(
		array(
			'import_file_name'           => 'Slake',
			'import_file_url'            => 'http://themes.dhrubok.website/wp-demos/slake-demo/files/slake_content.xml',
			'import_preview_image_url'   => 'http://themes.dhrubok.website/wp-demos/slake-demo/files/screenshot.png',
			'import_redux'               => array(
				array(
					'file_url'    => 'http://themes.dhrubok.website/wp-demos/slake-demo/files/theme_options.json',
					'option_name' => 'slake',
				),
			),
			'import_notice'              => esc_html__( 'After importing the demo, you need set your preferred homepage layout from ', 'slake') .
			'<a href="'. trailingslashit( esc_url( home_url('/') ) ) .'wp-admin/options-reading.php">'. esc_html__('here', 'slake') .'</a>',
		)
	);
}
add_filter( 'pt-ocdi/import_files', 'slake_import_files' );


/**
 *
 * Max Mega Menu theme for Slake
 *
 */
function slake_max_megamenu($themes) {
    $themes["slake_mega_menu__-_imported_1544345028"] = array(
        'title' => 'Slake Mega Menu',
        'container_background_from' => 'rgba(255, 255, 255, 0)',
        'container_background_to' => 'rgba(255, 255, 255, 0)',
        'arrow_up' => 'dash-f343',
        'arrow_down' => 'dash-f347',
        'arrow_left' => 'dash-f341',
        'arrow_right' => 'dash-f345',
        'menu_item_align' => 'right',
        'menu_item_background_hover_from' => 'rgba(255, 255, 255, 0)',
        'menu_item_background_hover_to' => 'rgba(255, 255, 255, 0)',
        'menu_item_link_font_size' => '12px',
        'menu_item_link_height' => '80px',
        'menu_item_link_color' => 'rgb(98, 109, 146)',
        'menu_item_link_weight' => 'inherit',
        'menu_item_link_text_transform' => 'uppercase',
        'menu_item_link_color_hover' => 'rgb(52, 100, 224)',
        'menu_item_link_padding_left' => '20px',
        'menu_item_link_padding_right' => '20px',
        'panel_background_from' => 'rgb(255, 255, 255)',
        'panel_background_to' => 'rgb(255, 255, 255)',
        'panel_header_color' => 'rgb(62, 68, 91)',
        'panel_header_text_transform' => 'capitalize',
        'panel_header_font_size' => '20px',
        'panel_header_border_color' => '#555',
        'panel_padding_left' => '30px',
        'panel_padding_right' => '30px',
        'panel_padding_top' => '40px',
        'panel_widget_padding_left' => '20px',
        'panel_widget_padding_right' => '10px',
        'panel_widget_padding_top' => '0px',
        'panel_widget_padding_bottom' => '40px',
        'panel_font_size' => '14px',
        'panel_font_color' => '#666',
        'panel_font_family' => 'inherit',
        'panel_second_level_font_color' => '#555',
        'panel_second_level_font_color_hover' => '#555',
        'panel_second_level_text_transform' => 'uppercase',
        'panel_second_level_font' => 'inherit',
        'panel_second_level_font_size' => '16px',
        'panel_second_level_font_weight' => 'bold',
        'panel_second_level_font_weight_hover' => 'bold',
        'panel_second_level_text_decoration' => 'none',
        'panel_second_level_text_decoration_hover' => 'none',
        'panel_second_level_border_color' => '#555',
        'panel_third_level_font_color' => 'rgb(62, 68, 91)',
        'panel_third_level_font_color_hover' => '#666',
        'panel_third_level_font' => 'inherit',
        'panel_third_level_font_size' => '16px',
        'flyout_width' => '250px',
        'flyout_menu_background_from' => 'rgb(255, 255, 255)',
        'flyout_menu_background_to' => 'rgb(255, 255, 255)',
        'flyout_border_color' => 'rgb(255, 255, 255)',
        'flyout_border_radius_top_left' => '0',
        'flyout_border_radius_top_right' => '0',
        'flyout_border_radius_bottom_left' => '10px',
        'flyout_border_radius_bottom_right' => '10px',
        'flyout_menu_item_divider_color' => 'rgb(233, 233, 233)',
        'flyout_padding_top' => '20px',
        'flyout_padding_bottom' => '20px',
        'flyout_link_padding_left' => '35px',
        'flyout_link_padding_right' => '40px',
        'flyout_link_padding_top' => '7px',
        'flyout_link_padding_bottom' => '5px',
        'flyout_link_weight' => 'inherit',
        'flyout_background_from' => 'rgb(255, 255, 255)',
        'flyout_background_to' => 'rgb(255, 255, 255)',
        'flyout_background_hover_from' => 'rgb(248, 249, 255)',
        'flyout_background_hover_to' => 'rgb(248, 249, 255)',
        'flyout_link_size' => '12px',
        'flyout_link_color' => 'rgb(62, 68, 91)',
        'flyout_link_color_hover' => 'rgb(52, 100, 224)',
        'flyout_link_family' => 'inherit',
        'responsive_breakpoint' => '780px',
        'toggle_background_from' => 'rgb(52, 100, 224)',
        'toggle_background_to' => 'rgb(52, 100, 224)',
        'mobile_background_from' => 'rgb(52, 100, 224)',
        'mobile_background_to' => 'rgb(52, 100, 224)',
        'mobile_menu_item_link_font_size' => '14px',
        'mobile_menu_item_link_color' => 'rgb(133, 133, 133)',
        'mobile_menu_item_link_text_align' => 'left',
        'mobile_menu_item_link_color_hover' => 'rgb(255, 255, 255)',
        'mobile_menu_item_background_hover_from' => 'rgb(52, 100, 224)',
        'mobile_menu_item_background_hover_to' => 'rgb(52, 100, 224)',
        'custom_css' => '/** Push menu onto new line **/
#{$wrap} {
    clear: both;
}',
    );
    return $themes;
}
add_filter("megamenu_themes", "slake_max_megamenu");
