<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Blog_Posts_2 extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'blog-posts-2';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blog Posts 2', 'slake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	 public function get_script_depends() {
 		return [ 'mailchimp-validate' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'slake-ts' ),
			]
		);

		$this->add_control(
			'limit',
			[
				'label' => __( 'Post Limit', 'slake-ts' ),
				'description'	=> __( 'Set the number of the posts to show or enter -1 to show all the posts.', 'slake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => -1
			]
		);

		$this->add_control(
			'blog_grid',
			[
				'label' => __( 'Blog Grid','slake-ts'),
				'type' => Controls_Manager::SELECT,
				'description' => __( 'Select Blog Grid Layout','slake-ts'),
				'default' => 'one-column',
				'options' => [
					'col-md-12' => __( 'One Column','slake-ts'),
					'col-md-6' => __( 'Two Column','slake-ts'),
					'col-md-4' => __( 'Three Column','slake-ts'),
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label' => __( 'Order By','slake-ts'),
				'type' => Controls_Manager::SELECT,
				'description' => __( 'Select post order by','slake-ts'),
				'default' => 'date',
				'options' => [
					'id' => esc_html__('ID', 'slake-ts'),
					'author' => esc_html__('author', 'slake-ts'),
					'title' => esc_html__('title', 'slake-ts'),
					'name' => esc_html__('name', 'slake-ts'),
					'type' => esc_html__('type', 'slake-ts'),
					'date' => esc_html__('date', 'slake-ts'),
					'modified' => esc_html__('modified', 'slake-ts'),
					'menu_order' => esc_html__('menu_order', 'slake-ts'),
					'rand' => esc_html__('modified', 'slake-ts'),
				],

			]
		);

		$this->add_control(
			'order',
			[
				'label' => __( 'Order ','slake-ts'),
				'type' => Controls_Manager::SELECT,
				'description' => __( 'Select post order','slake-ts'),
				'default' => 'DESC',
				'options' => [
					'DESC' => esc_html__('DESC', 'slake-ts'),
					'ASC' => esc_html__('ASC', 'slake-ts'),
				],

			]
		);

		$this->add_control(
			'show_excerpt',
			[
				'label' => __( 'Show Post Excerpt', 'slake-ts' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'slake-ts' ),
				'label_off' => __( 'Hide', 'slake-ts' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'show_meta__author',
			[
				'label' => __( 'Show Meta: Auhtor', 'slake-ts' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'slake-ts' ),
				'label_off' => __( 'Hide', 'slake-ts' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_meta__date',
			[
				'label' => __( 'Show Meta: Date', 'slake-ts' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'slake-ts' ),
				'label_off' => __( 'Hide', 'slake-ts' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'read_more_btn_text',
			[
				'label' => __( 'Read More Button Text', 'slake-ts' ),
				'description'	=> __( 'Enter the read more button text', 'slake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Read more', 'slake-ts')
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'slake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment', 'slake-ts' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'slake-ts' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'slake-ts' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'slake-ts' ),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'slake-ts' ),
						'icon' => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .blog-box-content' => 'text-align: {{VALUE}};',
				],
			]
		);


		$this->add_responsive_control(
			'padding',
			[
				'label' => __( 'Padding', 'slake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .blog-box-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin',
			[
				'label' => __( 'Padding', 'slake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .blog-box-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

		// Globalizing theme class

        ?>

		<div class="blog-style-2 row">

			<?php

				// Query for blog posts
				$args = array(
					'post_type' => 'post',
					'posts_per_page'   => $settings['limit'],
					'orderby'   => $settings['orderby'],
					'order'   => $settings['order'],
				);

				$posts = new \WP_Query( $args );



				if( $posts->have_posts() ) :

			        while( $posts->have_posts() ) : $posts->the_post(); ?>

			           	<div class="<?php echo $settings['blog_grid']; ?> blog-posts-column">
			           		<div class="single-blog">
								<?php
							        if( has_post_thumbnail() ) :
							            echo '<div class="single-blog-image">';
							                echo '<a href="'. esc_url( get_the_permalink() ) .'">';
							                    the_post_thumbnail();
							                echo '</a>';
							            echo '</div>';
							        endif;
							    ?>

								<div class="blog-box-content">


									<ul class="post-meta">

										<?php
											if( $settings['show_meta__author'] ) :
										?>
											<li>
												<span class="meta-wrap author-meta">

													<?php esc_html_e('By: ', 'slake'); ?>

													<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>">

														<?php
															the_author();
														?>
													</a>
												</span>
											</li>
										<?php endif; ?>


										<?php
											if( $settings['show_meta__date'] ) :
										?>
											<li>
												<span class="meta-wrap">
													<a href="<?php the_permalink(); ?>"> <?php echo esc_html( the_time( get_option('date_format') ) ) ; ?> </a>
												</span>
											</li>
										<?php endif; ?>

									</ul>


									<?php
										printf('<a href="%s"><h3>%s</h3></a>', esc_url( get_the_permalink() ), esc_html( get_the_title() ) );
									?>

									<?php

										if( $settings['show_excerpt'] == 'yes' ) :
											echo '<div class="blog-excerpt">';
												the_excerpt();
											echo '</div>';
										endif;

									?>

									<div class="post-permalink">

										<?php

											printf('<a href="%s">%s</a>', get_the_permalink(), $settings['read_more_btn_text'] . '<i class="ti-arrow-right"></i>');
										?>

									</div>

								</div>

			           		</div>
			           	</div>


					<?php
			        endwhile;
					wp_reset_postdata();


			    else:

			    endif;

			?>

		</div>

		<!--End mc_embed_signup-->
        <?php
	}

}
