<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Blog_Posts extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'blog-posts';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blog Posts', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	 public function get_script_depends() {
 		return [ 'mailchimp-validate' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'limit',
			[
				'label' => __( 'Post Limit', 'flake-ts' ),
				'description'	=> __( 'Set the number of the posts to show or enter -1 to show all the posts.', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => -1
			]
		);

		$this->add_control(
			'blog_grid',
			[
				'label' => __( 'Blog Grid','flake-ts'),
				'type' => Controls_Manager::SELECT,
				'description' => __( 'Select Blog Grid Layout','flake-ts'),
				'default' => 'one-column',
				'options' => [
					'one-column' => __( 'One Column','flake-ts'),
					'two-column' => __( 'Two Column','flake-ts'),
					'three-column' => __( 'Three Column','flake-ts'),
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label' => __( 'Order By','flake-ts'),
				'type' => Controls_Manager::SELECT,
				'description' => __( 'Select post order by','flake-ts'),
				'default' => 'date',
				'options' => [
					'id' => esc_html__('ID', 'flake-ts'),
					'author' => esc_html__('author', 'flake-ts'),
					'title' => esc_html__('title', 'flake-ts'),
					'name' => esc_html__('name', 'flake-ts'),
					'type' => esc_html__('type', 'flake-ts'),
					'date' => esc_html__('date', 'flake-ts'),
					'modified' => esc_html__('modified', 'flake-ts'),
					'menu_order' => esc_html__('menu_order', 'flake-ts'),
					'rand' => esc_html__('modified', 'flake-ts'),
				],

			]
		);

		$this->add_control(
			'order',
			[
				'label' => __( 'Order ','flake-ts'),
				'type' => Controls_Manager::SELECT,
				'description' => __( 'Select post order','flake-ts'),
				'default' => 'DESC',
				'options' => [
					'DESC' => esc_html__('DESC', 'flake-ts'),
					'ASC' => esc_html__('ASC', 'flake-ts'),
				],

			]
		);


		$this->end_controls_section();


		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment', 'flake-ts' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'flake-ts' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'flake-ts' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'flake-ts' ),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'flake-ts' ),
						'icon' => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .blog-box-content' => 'text-align: {{VALUE}};',
				],
			]
		);


		$this->add_responsive_control(
			'padding',
			[
				'label' => __( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .blog-box-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'margin',
			[
				'label' => __( 'Margin', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .blog-box-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

		// Globalizing theme class
		global $flakeObj;

		$grid = ($settings['blog_grid']) ? $settings['blog_grid'] : 'one-column';

        ?>

        <div class="row">

			<?php

				// Query for blog posts
				$args = array(
					'post_type' => 'post',
					'posts_per_page'   => $settings['limit'],
					'orderby'   => $settings['orderby'],
					'order'   => $settings['order'],
				);

				$posts = new \WP_Query( $args );



				if( $posts->have_posts() ) :

			        while( $posts->have_posts() ) : $posts->the_post();

			            get_template_part('templates/' . $grid );

			        endwhile;
					wp_reset_postdata();

			    else:
			        get_template_part('templates/no-posts');
			    endif;

			?>

		</div>

		<!--End mc_embed_signup-->
        <?php
	}

}
