<?php
namespace SlakeTS\Widgets;


use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Breadcrumb extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'breadcrumb';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Breadcrumb', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'breadcrumb_title',
			[
				'label' => __( 'Breadcrumb Title', 'flake-ts' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => 'Dedicated Shared Hosting at affortable Price',
			]
		);

		$this->add_control(
			'breadcrumb_img',
			[
				'label' => __( ' Breadcrumb Image', 'flake-ts' ),
				'type' => Controls_Manager::MEDIA,
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_separator',
			[
				'label' => __( 'Title', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment', 'flake-ts' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'flake-ts' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'flake-ts' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'flake-ts' ),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'flake-ts' ),
						'icon' => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .breadcrumb-content' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#fff',
				'selectors' => [
					'{{WRAPPER}} .breadcrumb-content' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .breadcrumb-content *',
				'scheme' => Scheme_Typography::TYPOGRAPHY_2,
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label' => __( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .breadcrumb-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'img_separator',
			[
				'label' => __( 'Image', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'img_display',
			[
				'label' => __( 'Image Display', 'flake-ts' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'block',
				'options' => [
					'block'  => __( 'Block', 'flake-ts' ),
					'inline_block' => __( 'Inline Block', 'flake-ts' ),
					'none' => __( 'None', 'flake-ts' ),
				],
				'selectors' => [
					'{{WRAPPER}} img.breadcrumb-right-img' => 'display: {{VALUE}};',
				],
			]
		);


		$this->add_responsive_control(
			'img_position',
			[
				'label' => __( 'Image Position', 'flake-ts' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'absolute',
				'options' => [
					'absolute'  => __( 'Absolute', 'flake-ts' ),
					'relative' => __( 'Relative', 'flake-ts' ),
					'inherit' => __( 'Inherit', 'flake-ts' ),
					'initial' => __( 'Initial', 'flake-ts' ),
					'fixed' => __( 'Fixed', 'flake-ts' ),
					'scroll' => __( 'Scroll', 'flake-ts' ),
				],
				'selectors' => [
					'{{WRAPPER}} img.breadcrumb-right-img' => 'position: {{VALUE}};',
				],
			]
		);


		$this->add_responsive_control(
			'img_width',
			[
				'label' => __( 'Width', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} img.breadcrumb-right-img' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'img_position_top',
			[
				'label' => __( 'Potition Top', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 50,
				],

				'selectors' => [
					'{{WRAPPER}} img.breadcrumb-right-img' => 'top: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'img_position_bottom',
			[
				'label' => __( 'Potition Bottom', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 50,
				],

				'selectors' => [
					'{{WRAPPER}} img.breadcrumb-right-img' => 'bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'img_position_left',
			[
				'label' => __( 'Potition Left', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 50,
				],

				'selectors' => [
					'{{WRAPPER}} img.breadcrumb-right-img' => 'left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'img_position_right',
			[
				'label' => __( 'Potition Right', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 50,
				],

				'selectors' => [
					'{{WRAPPER}} img.breadcrumb-right-img' => 'right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'img_position_right_override',
			[
				'label' => __( 'Potition Right Override', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'selectors' => [
					'{{WRAPPER}} img.breadcrumb-right-img' => 'right: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'breadcrumb_separator',
			[
				'label' => __( 'Breadcrumb', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);


		$this->add_control(
			'breadcrumb_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#fff',
				'selectors' => [
					'{{WRAPPER}} .breadcrumb-content h2' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'breadcrumb_typography',
				'selector' => '{{WRAPPER}} .breadcrumbs span',
				'scheme' => Scheme_Typography::TYPOGRAPHY_3,
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        $this->add_inline_editing_attributes('title', 'basic');
        $this->add_inline_editing_attributes('number', 'basic');
        $this->add_inline_editing_attributes('ff_image', 'none');

        ?>
			<div class="flake-breadcrumb">
				<div class="container">
					<div class="row">
						<div class="col-md-12">
							<div class="breadcrumb-content-table">
								<div class="breadcrumb-content">
									<?php echo $settings['breadcrumb_title']; ?>
								</div>
							</div>
							<?php echo $this->slake_breadcrumbs(); ?>

						</div>

						<?php
							if( $settings['breadcrumb_img']['url'] ) :
								printf('<img src="%s" alt="%s" class="breadcrumb-right-img">', $settings['breadcrumb_img']['url'], $settings['breadcrumb_title']);
							endif;
						?>

					</div>
				</div>
			</div>
        <?php
	}



		protected function slake_breadcrumbs() {

	        $slake = get_option( 'slake' );

			$sepOpt = ( isset( $slake['breadcrumb_sep'] ) ? $slake['breadcrumb_sep'] : '<i class="fa fa-angle-right"></i>' );

			/* === OPTIONS === */
			$text['home']     = esc_html__('Home', 'slake'); // text for the 'Home' link
			$text['category'] = esc_html__('Archive by Category "%s"', 'slake'); // text for a category page
			$text['search']   = esc_html__('Search Results for "%s" Query', 'slake'); // text for a search results page
			$text['tag']      = esc_html__('Posts Tagged "%s"', 'slake'); // text for a tag page
			$text['author']   = esc_html__('Articles Posted by %s', 'slake'); // text for an author page
			$text['404']      = esc_html__('Error 404', 'slake'); // text for the 404 page
			$text['page']     = esc_html__('Page %s', 'slake'); // text 'Page N'
			$text['cpage']    = esc_html__('Comment Page %s', 'slake'); // text 'Comment Page N'

			$wrap_before    = '<div class="breadcrumbs">'; // the opening wrapper tag
			$wrap_after     = '</div><!-- .breadcrumbs -->'; // the closing wrapper tag
			$sep            = $sepOpt; // separator between crumbs
			$sep_before     = '<span class="sep">'; // tag before separator
			$sep_after      = '</span>'; // tag after separator
			$show_home_link = 1; // 1 - show the 'Home' link, 0 - don't show
			$show_on_home   = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show
			$show_current   = 1; // 1 - show current page title, 0 - don't show
			$before         = '<span class="current">'; // tag before the current crumb
			$after          = '</span>'; // tag after the current crumb
			$output 		= '';
			/* === END OF OPTIONS === */

			global $post;
			$home_url       = esc_url( home_url('/') );
			$link_before    = '<span >';
			$link_after     = '</span>';
			$link_attr      = '';
			$link_in_before = '<span>';
			$link_in_after  = '</span>';
			$link           = $link_before . '<a href="%1$s"' . $link_attr . '>' . $link_in_before . '%2$s' . $link_in_after . '</a>' . $link_after;
			$frontpage_id   = get_option('page_on_front');

			if(  is_page() ) {
				$parent_id      = $post->post_parent;
			}
			$sep            = ' ' . $sep_before . $sep . $sep_after . ' ';
			$home_link      = $link_before . '<a href="' . $home_url . '"' . $link_attr . ' class="home">' . $link_in_before . $text['home'] . $link_in_after . '</a>' . $link_after;

			if ( is_home() || is_front_page() ) {

				if ($show_on_home) $output .= $wrap_before . $home_link . $wrap_after;

			} else {

				$output .= $wrap_before;
				if ($show_home_link) $output .= $home_link;

				if ( is_category() ) {
					$cat = get_category(get_query_var('cat'), false);
					if ($cat->parent != 0) {
						$cats = get_category_parents($cat->parent, TRUE, $sep);
						$cats = preg_replace("#^(.+)$sep$#", "$1", $cats);
						$cats = preg_replace('#<a([^>]+)>([^<]+)<\/a>#', $link_before . '<a$1' . $link_attr .'>' . $link_in_before . '$2' . $link_in_after .'</a>' . $link_after, $cats);
						if ($show_home_link) $output .= $sep;
						$output .= $cats;
					}
					if ( get_query_var('paged') ) {
						$cat = $cat->cat_ID;
						$output .= $sep . sprintf($link, get_category_link($cat), get_cat_name($cat)) . $sep . $before . sprintf($text['page'], get_query_var('paged')) . $after;
					} else {
						if ($show_current) $output .= $sep . $before . sprintf($text['category'], single_cat_title('', false)) . $after;
					}

				} elseif ( is_search() ) {
					if (have_posts()) {
						if ($show_home_link && $show_current) $output .= $sep;
						if ($show_current) $output .= $before . sprintf($text['search'], get_search_query()) . $after;
					} else {
						if ($show_home_link) $output .= $sep;
						$output .= $before . sprintf($text['search'], get_search_query()) . $after;
					}

				} elseif ( is_day() ) {
					if ($show_home_link) $output .= $sep;
					$output .= sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $sep;
					$output .= sprintf($link, get_month_link(get_the_time('Y'), get_the_time('m')), get_the_time('F'));
					if ($show_current) $output .= $sep . $before . get_the_time('d') . $after;

				} elseif ( is_month() ) {
					if ($show_home_link) $output .= $sep;
					$output .= sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y'));
					if ($show_current) $output .= $sep . $before . get_the_time('F') . $after;

				} elseif ( is_year() ) {
					if ($show_home_link && $show_current) $output .= $sep;
					if ($show_current) $output .= $before . get_the_time('Y') . $after;

				} elseif ( is_single() && !is_attachment() ) {
					if ($show_home_link) $output .= $sep;
					if ( get_post_type() != 'post' ) {
						$post_type = get_post_type_object(get_post_type());
						$slug = $post_type->rewrite;
						if ($show_current) $output .=  $before . get_the_title() . $after;
					} else {
						$cat = get_the_category(); $cat = $cat[0];
						$cats = get_category_parents($cat, TRUE, $sep);
						if (!$show_current || get_query_var('cpage')) $cats = preg_replace("#^(.+)$sep$#", "$1", $cats);
						$cats = preg_replace('#<a([^>]+)>([^<]+)<\/a>#', $link_before . '<a$1' . $link_attr .'>' . $link_in_before . '$2' . $link_in_after .'</a>' . $link_after, $cats);
						$output .= $cats;
						if ( get_query_var('cpage') ) {
							$output .= $sep . sprintf($link, get_permalink(), get_the_title()) . $sep . $before . sprintf($text['cpage'], get_query_var('cpage')) . $after;
						} else {
							if ($show_current) $output .= $before . get_the_title() . $after;
						}
					}

				// custom post type
				} elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
					$post_type = get_post_type_object(get_post_type());
					if ( get_query_var('paged') ) {
						$output .= $sep . sprintf($link, get_post_type_archive_link($post_type->name), $post_type->label) . $sep . $before . sprintf($text['page'], get_query_var('paged')) . $after;
					} else {
						if ($show_current) $output .= $sep . $before . $post_type->label . $after;
					}

				} elseif ( is_attachment() ) {
					if ($show_home_link) $output .= $sep;
					$parent = get_post($parent_id);
					$cat = get_the_category($parent->ID); $cat = $cat[0];
					if ($cat) {
						$cats = get_category_parents($cat, TRUE, $sep);
						$cats = preg_replace('#<a([^>]+)>([^<]+)<\/a>#', $link_before . '<a$1' . $link_attr .'>' . $link_in_before . '$2' . $link_in_after .'</a>' . $link_after, $cats);
						$output .= $cats;
					}
					printf($link, get_permalink($parent), $parent->post_title);
					if ($show_current) $output .= $sep . $before . get_the_title() . $after;

				} elseif ( is_page() && !$parent_id ) {
					if ($show_current) $output .= $sep . $before . get_the_title() . $after;

				} elseif ( is_page() && $parent_id ) {
					if ($show_home_link) $output .= $sep;
					if ($parent_id != $frontpage_id) {
						$breadcrumbs = array();
						while ($parent_id) {
							$page = get_page($parent_id);
							if ($parent_id != $frontpage_id) {
								$breadcrumbs[] = sprintf($link, get_permalink($page->ID), get_the_title($page->ID));
							}
							$parent_id = $page->post_parent;
						}
						$breadcrumbs = array_reverse($breadcrumbs);
						for ($i = 0; $i < count($breadcrumbs); $i++) {
							$output .= $breadcrumbs[$i];
							if ($i != count($breadcrumbs)-1) $output .= $sep;
						}
					}
					if ($show_current) $output .= $sep . $before . get_the_title() . $after;

				} elseif ( is_tag() ) {
					if ( get_query_var('paged') ) {
						$tag_id = get_queried_object_id();
						$tag = get_tag($tag_id);
						$output .= $sep . sprintf($link, get_tag_link($tag_id), $tag->name) . $sep . $before . sprintf($text['page'], get_query_var('paged')) . $after;
					} else {
						if ($show_current) $output .= $sep . $before . sprintf($text['tag'], single_tag_title('', false)) . $after;
					}

				} elseif ( is_author() ) {
					global $author;
					$author = get_userdata($author);
					if ( get_query_var('paged') ) {
						if ($show_home_link) $output .= $sep;
						$output .= sprintf($link, get_author_posts_url($author->ID), $author->display_name) . $sep . $before . sprintf($text['page'], get_query_var('paged')) . $after;
					} else {
						if ($show_home_link && $show_current) $output .= $sep;
						if ($show_current) $output .= $before . sprintf($text['author'], $author->display_name) . $after;
					}

				} elseif ( is_404() ) {
					if ($show_home_link && $show_current) $output .= $sep;
					if ($show_current) $output .= $before . $text['404'] . $after;

				} elseif ( has_post_format() && !is_singular() ) {
					if ($show_home_link) $output .= $sep;
					$output .= get_post_format_string( get_post_format() );
				}

				$output .= $wrap_after;

				return $output;

			}

		}

}
