<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.


class Contact_Form_7 extends Widget_Base {

	public function get_name() {
		return 'eael-contact-form';
	}

	public function get_title() {
		return esc_html__( 'Contact Form 7', 'flake-ts' );
	}

	public function get_icon() {
		return 'fa fa-envelope-o';
	}


    public function get_categories() {
	    return [ 'slake-addons' ];
	}

	protected function _register_controls() {


  		$this->start_controls_section(
  			'eael_section_wpcf7_form',
  			[
  				'label' => esc_html__( 'Contact Form', 'flake-ts' )
  			]
  		);

		$this->add_control(
			'eael_wpcf7_form',
			[
				'label' => esc_html__( 'Select your contact form 7', 'flake-ts' ),
				'label_block' => true,
				'type' => Controls_Manager::SELECT,
				'options' => eael_select_contact_form_stand_alone(),
			]
		);


		$this->end_controls_section();


		$this->start_controls_section(
			'eael_section_contact_form_styles',
			[
				'label' => esc_html__( 'Form Container Styles', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);

		$this->add_control(
			'eael_contact_form_background',
			[
				'label' => esc_html__( 'Form Background Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .get-in-touch' => 'background: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'eael_contact_form_alignment',
			[
				'label' => esc_html__( 'Form Alignment', 'flake-ts' ),
				'type' => Controls_Manager::CHOOSE,
				'label_block' => true,
				'options' => [
					'default' => [
						'title' => __( 'Default', 'flake-ts' ),
						'icon' => 'fa fa-ban',
					],
					'left' => [
						'title' => esc_html__( 'Left', 'flake-ts' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'flake-ts' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'flake-ts' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'default',
				'prefix_class' => 'eael-contact-form-align-',
			]
		);

  		$this->add_responsive_control(
  			'eael_contact_form_width',
  			[
  				'label' => esc_html__( 'Form Width', 'flake-ts' ),
  				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 1000,
					],
					'em' => [
						'min' => 1,
						'max' => 80,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch' => 'width: {{SIZE}}{{UNIT}};',
				],
  			]
  		);

  		$this->add_responsive_control(
  			'eael_contact_form_max_width',
  			[
  				'label' => esc_html__( 'Form Max Width', 'flake-ts' ),
  				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 1000,
					],
					'em' => [
						'min' => 1,
						'max' => 80,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch' => 'max-width: {{SIZE}}{{UNIT}};',
				],
  			]
  		);


		$this->add_responsive_control(
			'eael_contact_form_margin',
			[
				'label' => esc_html__( 'Form Margin', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'eael_contact_form_padding',
			[
				'label' => esc_html__( 'Form Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->add_control(
			'eael_contact_form_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'separator' => 'before',
				'size_units' => [ 'px' ],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'eael_contact_form_border',
				'selector' => '{{WRAPPER}} .get-in-touch',
			]
		);


		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'eael_contact_form_box_shadow',
				'selector' => '{{WRAPPER}} .get-in-touch',
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'eael_section_contact_form_field_styles',
			[
				'label' => esc_html__( 'Form Fields Styles', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);

		$this->add_control(
			'eael_contact_form_input_background',
			[
				'label' => esc_html__( 'Input Field Background', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-text, {{WRAPPER}} .get-in-touch textarea.wpcf7-textarea' => 'background: {{VALUE}};',
				],
			]
		);


  		$this->add_responsive_control(
  			'eael_contact_form_input_width',
  			[
  				'label' => esc_html__( 'Input Width', 'flake-ts' ),
  				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 1000,
					],
					'em' => [
						'min' => 1,
						'max' => 80,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-text' => 'width: {{SIZE}}{{UNIT}};',
				],
  			]
  		);

  		$this->add_responsive_control(
  			'eael_contact_form_textarea_width',
  			[
  				'label' => esc_html__( 'Textarea Width', 'flake-ts' ),
  				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 1000,
					],
					'em' => [
						'min' => 1,
						'max' => 80,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch textarea.wpcf7-textarea' => 'width: {{SIZE}}{{UNIT}};',
				],
  			]
  		);

		$this->add_responsive_control(
			'eael_contact_form_input_padding',
			[
				'label' => esc_html__( 'Fields Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-text, {{WRAPPER}} .get-in-touch textarea.wpcf7-textarea' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);



		$this->add_control(
			'eael_contact_form_input_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'separator' => 'before',
				'size_units' => [ 'px' ],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-text, {{WRAPPER}} .get-in-touch textarea.wpcf7-textarea' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'eael_contact_form_input_border',
				'selector' => '{{WRAPPER}} .get-in-touch input.wpcf7-text, {{WRAPPER}} .get-in-touch textarea.wpcf7-textarea',
			]
		);


		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'eael_contact_form_input_box_shadow',
				'selector' => '{{WRAPPER}} .get-in-touch input.wpcf7-text, {{WRAPPER}} .get-in-touch textarea.wpcf7-textarea',
			]
		);

		$this->add_control(
			'eael_contact_form_focus_heading',
			[
				'type' => Controls_Manager::HEADING,
				'label' => esc_html__( 'Focus State Style', 'flake-ts' ),
				'separator' => 'before',
			]
		);


		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'eael_contact_form_input_focus_box_shadow',
				'selector' => '{{WRAPPER}} .get-in-touch input.wpcf7-text:focus, {{WRAPPER}} .get-in-touch textarea.wpcf7-textarea:focus',
			]
		);

		$this->add_control(
			'eael_contact_form_input_focus_border',
			[
				'label' => esc_html__( 'Border Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'body {{WRAPPER}} .get-in-touch input.wpcf7-text:focus, body {{WRAPPER}} .get-in-touch textarea.wpcf7-textarea:focus' => 'border-color: {{VALUE}};',
				],
			]
		);



		$this->end_controls_section();


		$this->start_controls_section(
			'eael_section_contact_form_typography',
			[
				'label' => esc_html__( 'Color & Typography', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);


		$this->add_control(
			'eael_contact_form_label_color',
			[
				'label' => esc_html__( 'Label Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .get-in-touch, {{WRAPPER}} .get-in-touch .wpcf7-form label' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'eael_contact_form_field_color',
			[
				'label' => esc_html__( 'Field Font Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-text, {{WRAPPER}} .get-in-touch textarea.wpcf7-textarea' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'eael_contact_form_placeholder_color',
			[
				'label' => esc_html__( 'Placeholder Font Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .get-in-touch ::-webkit-input-placeholder' => 'color: {{VALUE}};',
					'{{WRAPPER}} .get-in-touch ::-moz-placeholder' => 'color: {{VALUE}};',
					'{{WRAPPER}} .get-in-touch ::-ms-input-placeholder' => 'color: {{VALUE}};',
				],
			]
		);


		$this->add_control(
			'eael_contact_form_label_heading',
			[
				'type' => Controls_Manager::HEADING,
				'label' => esc_html__( 'Label Typography', 'flake-ts' ),
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'eael_contact_form_label_typography',
				'selector' => '{{WRAPPER}} .get-in-touch, {{WRAPPER}} .get-in-touch .wpcf7-form label',
			]
		);


		$this->add_control(
			'eael_contact_form_heading_input_field',
			[
				'type' => Controls_Manager::HEADING,
				'label' => esc_html__( 'Input Fields Typography', 'flake-ts' ),
				'separator' => 'before',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'eael_contact_form_input_field_typography',
				'selector' => '{{WRAPPER}} .get-in-touch input.wpcf7-text, {{WRAPPER}} .get-in-touch textarea.wpcf7-textarea',
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'eael_section_contact_form_submit_button_styles',
			[
				'label' => esc_html__( 'Submit Button Styles', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);

  		$this->add_responsive_control(
  			'eael_contact_form_submit_btn_width',
  			[
  				'label' => esc_html__( 'Button Width', 'flake-ts' ),
  				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 1000,
					],
					'em' => [
						'min' => 1,
						'max' => 80,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-submit' => 'width: {{SIZE}}{{UNIT}};',
				],
  			]
  		);

		$this->add_responsive_control(
			'eael_contact_form_submit_btn_alignment',
			[
				'label' => esc_html__( 'Button Alignment', 'flake-ts' ),
				'type' => Controls_Manager::CHOOSE,
				'label_block' => true,
				'options' => [
					'default' => [
						'title' => __( 'Default', 'flake-ts' ),
						'icon' => 'fa fa-ban',
					],
					'left' => [
						'title' => esc_html__( 'Left', 'flake-ts' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'flake-ts' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'flake-ts' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'default',
				'prefix_class' => 'eael-contact-form-btn-align-',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
             'name' => 'eael_contact_form_submit_btn_typography',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .get-in-touch input.wpcf7-submit',
			]
		);

		$this->add_responsive_control(
			'eael_contact_form_submit_btn_margin',
			[
				'label' => esc_html__( 'Margin', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-submit' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->add_responsive_control(
			'eael_contact_form_submit_btn_padding',
			[
				'label' => esc_html__( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-submit' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);



		$this->start_controls_tabs( 'eael_contact_form_submit_button_tabs' );

		$this->start_controls_tab( 'normal', [ 'label' => esc_html__( 'Normal', 'flake-ts' ) ] );

		$this->add_control(
			'eael_contact_form_submit_btn_text_color',
			[
				'label' => esc_html__( 'Text Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-submit' => 'color: {{VALUE}};',
				],
			]
		);



		$this->add_control(
			'eael_contact_form_submit_btn_background_color',
			[
				'label' => esc_html__( 'Background Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-submit' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'eael_contact_form_submit_btn_border',
				'selector' => '{{WRAPPER}} .get-in-touch input.wpcf7-submit',
			]
		);

		$this->add_control(
			'eael_contact_form_submit_btn_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-submit' => 'border-radius: {{SIZE}}px;',
				],
			]
		);



		$this->end_controls_tab();

		$this->start_controls_tab( 'eael_contact_form_submit_btn_hover', [ 'label' => esc_html__( 'Hover', 'flake-ts' ) ] );

		$this->add_control(
			'eael_contact_form_submit_btn_hover_text_color',
			[
				'label' => esc_html__( 'Text Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-submit:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'eael_contact_form_submit_btn_hover_background_color',
			[
				'label' => esc_html__( 'Background Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-submit:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'eael_contact_form_submit_btn_hover_border_color',
			[
				'label' => esc_html__( 'Border Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .get-in-touch input.wpcf7-submit:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();


		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'eael_contact_form_submit_btn_box_shadow',
				'selector' => '{{WRAPPER}} .get-in-touch input.wpcf7-submit',
			]
		);


		$this->end_controls_section();


	}


	protected function render( ) {

      $settings = $this->get_settings();


	?>


	<?php if ( ! empty( $settings['eael_wpcf7_form'] ) ) : ?>
		<div class="get-in-touch">
			<?php echo do_shortcode( '[contact-form-7 id="' . $settings['eael_wpcf7_form'] . '" ]' ); ?>
		</div>
	<?php endif; ?>

	<?php

	}

	protected function content_template() {''

		?>


		<?php
	}
}
