<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Domain_Search extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'domain-search';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Domain Search', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'form_style',
			[
				'label' => __( 'Select Form Style', 'flake-ts' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'style-1' => __('Style 1', 'flake-ts'),
					'style-2' => __('Style 2', 'flake-ts')
				],
				'default' => 'style-1'
			]
		);

		$this->add_control(
			'input_placehoder',
			[
				'label' => __( 'Input Placeholder Text', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Enter your domain here',
			]
		);

		$this->add_control(
			'button_value',
			[
				'label' => __( 'Button Value Text', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Search',
			]
		);

		$this->add_control(
			'domain_tlds',
			[
				'label' => __( 'Domain TLD Lists', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'domain',
						'label' => __( 'Domain name', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
				],
				'default' => [
					[
						'domain' => '.com'
					],
					[
						'domain' => '.net'
					],
					[
						'domain' => '.org'
					]
				]

			]
		);

		$this->add_control(
			'error_text',
			[
				'label' => __( 'Error Message', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Please enter a domain name',
			]
		);

		$this->add_control(
			'failed_error_text',
			[
				'label' => __( 'Failed Error Message', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => 'Error occured',
			]
		);

		$this->add_control(
			'inline_domain_form',
			[
				'label' => __( 'Inline Domain Form?', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'your-plugin' ),
				'label_off' => __( 'No', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);




		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'background_color',
			[
				'label' => __( 'Background Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .domain-checkup' => 'background: {{VALUE}};'
				],
			]
		);

		$this->add_control(
			'domain_list_accent_color',
			[
				'label' => __( 'Domain List Accent Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .domain-checkup-left .nice-select .option:hover, {{WRAPPER}} .nice-select .option.focus, {{WRAPPER}} .nice-select .option.selected.focus' => 'color: {{VALUE}};',
					'{{WRAPPER}} .domain-checkup-left li.option.selected.focus:after' => 'background: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __( 'Button Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .domain-checkup-right button' => 'background: {{VALUE}};'
				],
			]
		);


		$this->add_control(
			'button_hover_color',
			[
				'label' => __( 'Button Hover Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .domain-checkup-right button:hover' => 'background: {{VALUE}};'
				],
			]
		);



		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
			$settings = $this->get_settings();

			$domain_options = array(
				'error_text' => $settings['error_text'],
				'failed_error_text' => $settings['failed_error_text']
			);

			$domain_checkup_classes = array( 'domain-checkup');

			$domain_checkup_classes[] = $settings['form_style'];

			$domain_options = json_encode( $domain_options );

        ?>


			<div class="<?php echo implode(' ', $domain_checkup_classes); ?>">
	            <form action="./" class="domainForm <?php if( $settings['inline_domain_form'] == 'yes' ) echo 'inline-domain-form'; ?>" method="post" data-form-options='<?php echo $domain_options; ?>'>
	                <div class="domain-checkup-left">
	                    <div class="input-field-row">
	                        <input type="text" class="domain-input" placeholder="<?php echo $settings['input_placehoder']; ?>" name="domain_name" id="domain_name">

							 <?php if( $settings['inline_domain_form'] !== 'yes' ) : ?>
		                        <select class="nice-select" name="domain_tld" id="domain_tld">
									<?php
										foreach( $settings['domain_tlds'] as $domain ) {
											printf('<option value="%s">%s</option>', $domain['domain'], $domain['domain']);
										}
									?>
		                        </select>
							<?php endif; ?>
	                    </div>
	                </div>
	                <div class="domain-checkup-right">
	                    <button class="domain-search-btn">
	                        <span class="button-value">
								<img src="<?php echo get_template_directory_uri() . '/assets/img/search-icon.png' ?>" alt="Search icon" >
		                        <?php echo $settings['button_value']; ?>
	                        </span>
							<span class="button-loader">
								<i class="fa fa-circle-o-notch fa-spin"></i>
							</span>
	                    </button>
	                </div>
	            </form>
	        </div>

			<div id="results" class="domain-search-result"></div>

        <?php
	}

}
