<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class FAQ extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'faq';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Slake FAQ', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'faqs',
			[
				'label' => __( 'FAQ', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'make_it_active',
						'label' => __( 'Make it active?', 'flake-ts' ),
						'type' => Controls_Manager::SWITCHER,
						'label_on' => __( 'Active', 'flake-ts' ),
						'label_off' => __( 'No', 'flake-ts' ),
						'return_value' => 'yes',
						'default' => 'no',
					],
					[
						'name' => 'question',
						'label' => __( 'Question', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'answer',
						'label' => __( 'Answer', 'flake-ts' ),
						'type' => Controls_Manager::WYSIWYG,
					]
				],

			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Accent Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .blue-btn' => 'background: {{VALUE}};',
					'{{WRAPPER}} .pricing-amount .price, {{WRAPPER}} .pricing-amount .currency' => 'color: {{VALUE}};'
				],
			]
		);



		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
			$settings = $this->get_settings();

        ?>

			<div class="faq-area" role="tablist">

				<?php

					$unique_parent = uniqid();

					foreach ( $settings['faqs'] as $faq ) :
						$unique_id = uniqid();
					?>


					<div class="panel panel-default">
						<div class="panel-heading" role="tab" id="heading-<?php echo $unique_id; ?>">
							<h4 class="panel-title">
								<a class="collapsed" role="button" data-toggle="collapse" data-parent="#accordion1" href="#faq-<?php echo $unique_id; ?>" aria-expanded="false" aria-controls="faq-<?php echo $unique_id; ?>">
									<?php echo $faq['question']; ?>
									<span class="ti-angle-down"></span>
								</a>
							</h4>
						</div>
						<div id="faq-<?php echo $unique_id; ?>" class="panel-collapse collapse <?php if( $faq['make_it_active'] == 'yes' ) echo ' in'; ?>" role="tabpanel" aria-labelledby="heading-<?php echo $unique_id; ?>">
							<div class="panel-body">
								<?php echo $faq['answer']; ?>
							</div>
						</div>
					</div>
				<?php


					endforeach; ?>
			</div>

        <?php
	}

}
