<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Feature_Block extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'feature-block';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Feature Block', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'flake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => 'Free Domain',
			]
		);

		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'flake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => 'Lorem ipsum dolor sittem ametam ngcing elit, per sed do eiusmoad teimpor inunt ut segad do eiusmod.',
			]
		);

		$this->add_control(
			'feature_img',
			[
				'label' => __( 'Feature image', 'flake-ts' ),
				'type' => Controls_Manager::MEDIA,
			]
		);

		$this->add_control(
			'use_button',
			[
				'label' => __( 'Use Read More Button?', 'flake-ts' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'flake-ts' ),
				'label_off' => __( 'No', 'flake-ts' ),
				'default' => 'no',
			]
		);

		$this->add_control(
			'button_text',
			[
				'label' => __( 'Button Text', 'flake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __('Read more', 'flake-ts'),
				'condition' => [
                    'use_button' => 'yes'
                ]
			]
		);

		$this->add_control(
			'button_link',
			[
				'label' => __( 'Button Text', 'flake-ts' ),
				'type' => Controls_Manager::URL,
				'default' => [
					'url' => '',
					'is_external' => false,
					'nofollow' => false,
				],
				'condition' => [
                    'use_button' => 'yes'
                ]
			]
		);

		$this->add_control(
			'use_icon',
			[
				'label' => __( 'Use Icon', 'vapp-ts' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
					'no' => __('No', 'vapp-ts'),
					'yes' => __('Yes', 'vapp-ts'),
				],
                'default' => 'no',
				'condition' => [
					'use_button' => 'yes'
				]
			]
		);

		$this->add_control(
			'icon',
			[
				'label' => __( 'Icon', 'vapp-ts' ),
                'type'    => Controls_Manager::ICON,
				'options' => slake_font_icons(),
				'condition' => [
					'use_icon' => 'yes',
					'use_button' => 'yes'
				]
			]
		);

		$this->add_control(
			'icon_position',
			[
				'label' => __( 'Icon Position', 'vapp-ts' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'left' => __('Left', 'vapp-ts'),
					'right' => __('Right', 'vapp-ts'),
				],
				'default' => 'left',
				'condition' => [
					'use_icon' => 'yes',
					'use_button' => 'yes'
				]
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment', 'flake-ts' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'flake-ts' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'flake-ts' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'flake-ts' ),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'flake-ts' ),
						'icon' => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-feature-block' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_separator',
			[
				'label' => __( 'Title', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);


		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#536d87',
				'selectors' => [
					'{{WRAPPER}} .single-feature-block h2' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);
		$this->add_control(
			'title_hover_color',
			[
				'label' => __( 'Hover Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#536d87',
				'selectors' => [
					'{{WRAPPER}} .single-feature-block:hover h2' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_2,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .single-feature-block h2',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);


		$this->add_responsive_control(
			'title_padding',
			[
				'label' => __( 'Spacing', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .single-feature-block h2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'description_label',
			[
				'label' => __( 'Description', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-feature-block p' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'subtitle_typography',
				'selector' => '{{WRAPPER}} .single-feature-block p',
				'scheme' => Scheme_Typography::TYPOGRAPHY_2,
			]
		);


		$this->add_responsive_control(
			'desc_padding',
			[
				'label' => __( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .single-feature-block p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'desc_margin',
			[
				'label' => __( 'Margin', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .single-feature-block p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'button_label',
			[
				'label' => __( 'Button', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-feature-block a' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_4,
				],
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label' => __( 'Hover Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single-feature-block a:hover' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .single-feature-block a',
				'scheme' => Scheme_Typography::TYPOGRAPHY_3,
			]
		);


		$this->add_responsive_control(
			'button_spacing',
			[
				'label' => __( 'Spacing', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .single-feature-block a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'button_icon_label',
			[
				'label' => __( 'Button Icon', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'button_icon_spacing',
			[
				'label' => __( 'Spacing', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .single-feature-block a i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        $this->add_inline_editing_attributes('title', 'none');
        $this->add_inline_editing_attributes('description', 'none');
        $this->add_inline_editing_attributes('feature_img', 'none');

        ?>

			<div class="single-feature-block">
				<?php if( $settings['feature_img']['url'] ) : ?>
	                <img <?php echo $this->get_render_attribute_string( 'feature_img.url' ); ?> src="<?php echo $settings['feature_img']['url']; ?>" alt="<?php echo $settings['title']; ?>">
				<?php endif; ?>
			    <h2 <?php echo $this->get_render_attribute_string('title');?>><?php echo $settings['title']; ?></h2>
			    <p <?php echo $this->get_render_attribute_string('description');?>><?php echo $settings['description']; ?> </p>

				<?php
					if( $settings['use_button'] == 'yes' ) :

						$url = $settings['button_link']['url'];
						$target = $settings['button_link']['is_external'] ? ' target="_blank"' : '';
						$nofollow = $settings['button_link']['nofollow'] ? ' rel="nofollow"' : '';

						$text = $settings['button_text'];

						if( $settings['use_icon'] == 'yes' ) {

							$icon_text = '<i class="'. $settings['icon'] .'"></i>';

							if( $settings['icon_position'] == 'left' ) :
								$text = $icon_text . $text;
							else:
								$text = $text . $icon_text;
							endif;

						}

						printf('<a href="%s" %s %s>%s</a>', $url, $target, $nofollow, $text);

					endif;
				?>
			</div>

        <?php
	}

}
