<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Features_Slider extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'features-slider';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Features Slider', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
	    return [ 'slake-addons' ];
	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'feature_sliders',
			[
				'label' => __( 'Feature Sliders', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'title',
						'label' => __( 'Title', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __( 'Reseller Hosting' , 'flake-ts' ),
						'label_block' => true,
					],
					[
						'name' => 'description',
						'label' => __( 'Description', 'flake-ts' ),
						'type' => Controls_Manager::TEXTAREA,
						'show_label' => false,
					],
					[
						'name' => 'image',
						'label' => __( 'Image', 'flake-ts' ),
						'type' => Controls_Manager::MEDIA,
						'show_label' => false,
					]
				],
				'default' => [
					[
						'title' => __( 'Web Hosting', 'flake-ts' ),
						'description' => __( 'Lorem ipsum dolor sittem ametam ngcing elit, per sed teimpor inunt ut sedig do eiusmod.', 'flake-ts' ),
					],
					[
						'title' => __( 'Reseller Hosting', 'flake-ts' ),
						'description' => __( 'Lorem ipsum dolor sittem ametam ngcing elit, per sed teimpor inunt ut sedig do eiusmod.', 'flake-ts' ),
					]

				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __( 'Box Shadow', 'flake-ts' ),
				'selector' => '{{WRAPPER}} .service-teatimonial-single-item .service-teatimonial-item-inner:hover',
			]
		);

		$this->add_control(
			'title_separator',
			[
				'label' => __( 'Title', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#3e445b',
				'selectors' => [
					'{{WRAPPER}} .service-teatimonial-item-inner h2' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);

		$this->add_control(
			'title_hover:color',
			[
				'label' => __( 'Hover Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#5dafef',
				'selectors' => [
					'{{WRAPPER}} .service-teatimonial-item-inner:hover h2' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .service-teatimonial-item-inner h2',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label' => __( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .service-teatimonial-item-inner h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'description_separator',
			[
				'label' => __( 'Description', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#536d87',
				'selectors' => [
					'{{WRAPPER}} .service-teatimonial-item-inner p' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_2,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description_typography',
				'selector' => '{{WRAPPER}} .service-teatimonial-item-inner p',
				'scheme' => Scheme_Typography::TYPOGRAPHY_2,
			]
		);

		$this->add_responsive_control(
			'description_padding',
			[
				'label' => __( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .service-teatimonial-item-inner p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'image_separator',
			[
				'label' => __( 'Image', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'img_min_height',
			[
				'label' => __( 'Min Height', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 50,
						'max' => 300,
						'step' => 2,
					]
				],
				'default' => [
					'unit' => 'px',
					'size' => 90,
				],
				'selectors' => [
					'{{WRAPPER}} .service-teatimonial .service-teatimonial-single-item .service-teatimonial-item-inner img' => 'min-height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="service-teatimonial">
			<?php
				if( count( $settings['feature_sliders'] ) > 0 ) :
					foreach( $settings['feature_sliders'] as $slider ) :
			?>
						<div class="service-teatimonial-single-item">
							<div class="service-teatimonial-item-inner">
								<img src="<?php echo $slider['image']['url'] ?>" alt="<?php echo $slider['title'] ?>">
								<h2><?php echo $slider['title'] ?></h2>
								<p><?php echo $slider['description'] ?></p>
							</div>
						</div>
			<?php
					endforeach;
				endif;
			?>

		</div>
		<div class="slider-btns-1">
			<button class="service-nav-left"><span class="ti-angle-left"></span></button>
			<button class="service-nav-right"><span class="ti-angle-right"></span></button>
		</div>

        <?php
	}

}
