<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Features_Tab extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'features-tab';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Features Tab', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);


		$this->add_control(
			'features_tab',
			[
				'label' => __( 'Features Tab', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'tab_title',
						'label' => __( 'Tab title', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'tab_active',
						'label' => __( 'Make it active?', 'flake-ts' ),
						'type' => Controls_Manager::SWITCHER,
						'label_on' => __( 'Show', 'flake-ts' ),
						'label_off' => __( 'Hide', 'flake-ts' ),
						'return_value' => 'yes',
						'default' => 'no',
					],
					[
						'name' => 'tab_content',
						'label' => __( 'Tab Content', 'flake-ts' ),
						'type' => Controls_Manager::WYSIWYG,
					],
					[
						'name' => 'content_image',
						'label' => __( 'Content image', 'flake-ts' ),
						'type' => Controls_Manager::MEDIA,
					]
				],

			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Accent Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} ul.tab-links li.active a:after, {{WRAPPER}}  .features-tab ul li:before' => 'background: {{VALUE}};',
					'{{WRAPPER}} ul.tab-links li.active a' => 'color: {{VALUE}};'
				],
			]
		);



		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<div class="tabs animated-slide-2  ">
			<ul class="tab-links">
				<?php
					$counter = 1;
					foreach ($settings['features_tab'] as $tabs) {

						if( $tabs['tab_active'] == 'yes' ) {
							printf( '<li class="active"><a href="#tab-%s">%s</a></li>', $counter, $tabs['tab_title'] );
						} else {
							printf( '<li><a href="#tab-%s">%s</a></li>', $counter, $tabs['tab_title'] );
						}

						$counter++;
					}
				?>
			</ul>
			<div class="tab-content features-tab">

				<?php
					$counter_tab = 1;
					foreach ($settings['features_tab'] as $tabs) : ?>

						<div id="tab-<?php echo $counter_tab; ?>" class="tab <?php if( $tabs['tab_active'] ) echo ' active'; ?>">
							<div class="row">
								<div class="col-md-7">
									<?php echo $tabs['tab_content']; ?>
								</div>
								<div class="icon-right">
									<img src="<?php echo $tabs['content_image']['url']; ?>" alt="<?php echo $tabs['content_title']; ?>">
								</div>
							</div>
						</div>

				<?php
					$counter_tab++;
					endforeach;
				?>


			</div>
		</div>

        <?php
	}

}
