<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Google_Map extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'google-map';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Google Map', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}



	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	 public function get_script_depends() {
 		return [ 'flake-map-1' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);


		$this->add_control(
			'title',
			[
				'label' => __( 'Address Title', 'flake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '28 Green Tower, Street Name, New York City, USA'
			]
		);

		$this->add_control(
			'address_phone',
			[
				'label' => __( 'Address Phone', 'flake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => '+880044 545 989 626'
			]
		);

		$this->add_control(
			'latitude',
			[
				'label' => __( 'Latitude', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => '40.6700'
			]
		);

		$this->add_control(
			'longitude',
			[
				'label' => __( 'Longitude', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => '-73.9400'
			]
		);

		$this->add_control(
			'map_icon',
			[
				'label' => __( 'Map Icon', 'flake-ts' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);




		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment', 'flake-ts' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'flake-ts' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'flake-ts' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'flake-ts' ),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'flake-ts' ),
						'icon' => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-address' => 'text-align: {{VALUE}};',
				],
			]
		);


		$this->add_responsive_control(
			'title_bottom_space',
			[
				'label' => __( 'Map Height', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'selectors' => [
					'{{WRAPPER}} #map' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

		$site_url = get_site_url();
		$theme_dir = get_template_directory_uri();

		$map_icon = '';

		if( $settings['map_icon'] ) {
	        $map_icon = $settings['map_icon'];
		} else {
			$map_icon =  $theme_dir . '/assets/img/map-marker-icon.png';
		}

		$map_options = array(
			'title'	=> $settings['title'],
			'address_phone'	=> $settings['address_phone'],
			'latitude'	=> $settings['latitude'],
			'longitude'	=> $settings['longitude'],
			'map_icon_mark'	=> $settings['map_icon']['url'],
			'show_map_info_window'	=> $settings['show_map_info_window'],
		);

		$map_options = json_encode($map_options);
        ?>
			<div id="map" data-map-options='<?php echo esc_attr( $map_options ); ?>'></div>
        <?php
	}

}
