<?php
namespace SlakeTS\Widgets;

use SlakeTS\Shortcodes\SlakeShortcodes;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Hero_Header_1 extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'hero-header-1';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Hero Header 1', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'sliders',
			[
				'label' => __( 'Sliders', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'title',
						'label' => __( 'Title', 'flake-ts' ),
						'type' => Controls_Manager::TEXTAREA,
						'default' => __('Best Hosting Provider for your Business', 'flake-ts')
					],
					[
						'name' => 'description',
						'label' => __( 'Description', 'flake-ts' ),
						'type' => Controls_Manager::TEXTAREA,
						'default' => __('Lorem ipsum dolor sittem ametam ngcing elit, per sed do eiusmoad teimpor inunt ut sed psum dolorre Lorem ipsum dolor sittem amit', 'flake-ts')
					],
					[
						'name' => 'first_btn_label',
						'label' => __( 'First Button Label', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __('Get Started Now', 'flake-ts')

					],
					[
						'name' => 'first_btn_url',
						'label' => __( 'First Button URL', 'flake-ts' ),
						'type' => Controls_Manager::URL,
						'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						],
					],
					[
						'name' => 'second_btn_label',
						'label' => __( 'Second Button Label', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __('See Pricing', 'flake-ts')
					],
					[
						'name' => 'second_btn_url',
						'label' => __( 'Second Button URL', 'flake-ts' ),
						'type' => Controls_Manager::URL,
						'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						],
					],
					[
						'name' => 'content_animation',
						'label' => __( 'Content Animation Style', 'flake-ts' ),
						'type' => Controls_Manager::SELECT2,
						'options' => SlakeShortcodes::animation_style_list(),
						'default' => 'slideInLeft'
					],
					[
						'name' => 'content_animation_duration',
						'label' => __( 'Content Animation Duration', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => '2s',
					],
					[
						'name' => 'content_animation_delay',
						'label' => __( 'Content Animation Delay', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => '0.4s',
					],
					[
						'name' => 'slider_img',
						'label' => __( 'Slider Image', 'flake-ts' ),
						'type' => Controls_Manager::MEDIA,
						'default' => [
							'url' => Utils::get_placeholder_image_src(),
						],
					],

					[
						'name' => 'image_animation',
						'label' => __( 'Image Animation Style', 'flake-ts' ),
						'type' => Controls_Manager::SELECT2,
						'options' => SlakeShortcodes::animation_style_list(),
						'default' => 'slideInRight'
					],
					[
						'name' => 'image_animation_duration',
						'label' => __( 'Image Animation Duration', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => '2s',
					],
					[
						'name' => 'image_animation_delay',
						'label' => __( 'Image Animation Delay', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => '0.4s',
					],
				],
				'default' => [
					[
						'title' => __('Best Hosting Provider for your Business', 'flake-ts'),
						'description' => __('Best Hosting Provider for your Business', 'flake-ts'),
						'first_btn_label' => __('Get Started Now', 'flake-ts'),
						'second_btn_label' => __('See Pricing', 'flake-ts'),
						'slider_img' => Utils::get_placeholder_image_src()
					],
					[
						'title' => __('Best Hosting Provider for your Business', 'flake-ts'),
						'description' => __('Best Hosting Provider for your Business', 'flake-ts'),
						'first_btn_label' => __('Get Started Now', 'flake-ts'),
						'second_btn_label' => __('See Pricing', 'flake-ts'),
						'slider_img' => Utils::get_placeholder_image_src()
					]
				]

			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .slider-content h2' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .slider-content h2',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);



		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .slider-content p' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_2,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description_typography',
				'selector' => '{{WRAPPER}} .slider-content p',
				'scheme' => Scheme_Typography::TYPOGRAPHY_2,
			]
		);

		$this->add_control(
			'button',
			[
				'label' => __( 'Button', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .slider-content .slider-links a.action-btn' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->add_control(
			'button_background',
			[
				'label' => __( 'Background', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .slider-content .slider-links a.action-btn' => 'background: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_4,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .slider-content .slider-links a.action-btn',
				'scheme' => Scheme_Typography::TYPOGRAPHY_3,
			]
		);


		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
			$settings = $this->get_settings();

        ?>
		<!-- HOMEPAGE-1 SLIDER -->
	    <section class="slider-1-bg">

	        <div class="home-1-bg-animation">
	            <ul>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/1.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/2.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/3.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/4.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/5.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/6.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/7.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/8.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/9.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/10.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/11.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/12.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/13.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/14.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/15.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/16.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/17.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/18.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/19.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/20.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/21.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/22.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/23.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/24.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/25.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/26.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/27.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/28.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/29.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/30.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/31.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/32.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/33.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/34.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/35.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/36.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/37.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/38.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/39.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/40.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/1.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/2.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/3.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/4.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/15.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/11.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/12.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/13.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/14.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/17.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/18.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/19.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/20.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/21.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/22.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/23.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/24.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/25.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/26.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/27.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/28.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/29.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/30.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/31.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/32.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/33.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/34.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/35.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/36.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/37.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/1.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/2.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/3.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/4.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/5.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/6.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/7.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/8.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/9.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/10.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/11.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/12.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/13.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/14.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/15.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/16.png" alt=""></li>
	                <li><img src="<?php echo get_template_directory_uri(); ?>/assets/img/svg-images/17.png" alt=""></li>
	            </ul>
	        </div>
	        <div class="homepage-slider-1">

				<?php foreach( $settings['sliders'] as $slide) : ?>
		            <div class="single-slider-item">
		                <div class="container">
		                    <div class="row slider-content-area">
		                        <?php
									printf(
										'<div class="col-md-7 col-sm-7 wow %s" data-wow-duration="%s" data-wow-delay="%s">',
										$slide['content_animation'],
										$slide['content_animation_duration'],
										$slide['content_animation_delay']
									);
								?>
		                            <div class="slider-content">
		                                <h2><?php echo $slide['title'] ?></h2>
		                                <p><?php echo $slide['description']; ?></p>
		                                <div class="slider-links">
											<?php
												// Echoing the first button
												if( $slide['first_btn_label'] ) :
													$first_btn_target = $slide['first_btn_url']['is_external'] ? ' target="_blank"' : '';
													$first_btn_nofollow = $slide['first_btn_url']['nofollow'] ? ' rel="nofollow"' : '';

													printf(
														'<a class="pricing-btn blue-btn homepage-one-all-features-btn action-btn slider-links-1" href="%s" %s %s>%s</a>',
														$slide['first_btn_url']['url'],
														$first_btn_target,
														$first_btn_nofollow,
														$slide['first_btn_label']
													);
												endif;

												// Echoing the second button
												if( $slide['second_btn_label'] ) :
													$second_btn_target = $slide['second_btn_url']['is_external'] ? ' target="_blank"' : '';
													$second_btn_nofollow = $slide['second_btn_url']['nofollow'] ? ' rel="nofollow"' : '';

													printf(
														'<a class="pricing-btn blue-btn homepage-one-all-features-btn action-btn slider-links-2" href="%s" %s %s>%s</a>',
														$slide['second_btn_url']['url'],
														$second_btn_target,
														$second_btn_nofollow,
														$slide['second_btn_label']
													);
												endif;

											?>
		                                </div>
		                            </div>
		                        </div>
		                    </div>
							<?php
								printf(
									'<img src="%s" alt="%s" class="position-img wow %s" data-wow-duration="%s" data-wow-delay="%s">',
									$slide['slider_img']['url'],
									$slide['title'],
									$slide['image_animation'],
									$slide['image_animation_duration'],
									$slide['image_animation_delay']
								);
							?>

		                </div>
		            </div>
				<?php endforeach; ?>

	        </div>
	    </section>

        <?php
	}

}
