<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Info_Block extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'info-block';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Info Block', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'flake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => 'Supper VPS Hosting',
			]
		);

		$this->add_control(
			'description',
			[
				'label' => __( 'Description', 'flake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusm tempor incididunt ut labore et dolore magna aliqua',
			]
		);

		$this->add_control(
			'price',
			[
				'label' => __( 'Price', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => '19',
			]
		);

		$this->add_control(
			'currency_sign',
			[
				'label' => __( 'Currency Sign', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => '$',
			]
		);

		$this->add_control(
			'duration',
			[
				'label' => __( 'Subscribe Duration', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => '/Annualy',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment', 'flake-ts' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'flake-ts' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'flake-ts' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'flake-ts' ),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'flake-ts' ),
						'icon' => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .feature-one-left' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_separator',
			[
				'label' => __( 'Title', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);


		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#3e445b',
				'selectors' => [
					'{{WRAPPER}} .feature-one-left h2' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .feature-one-left h2',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label' => __( 'Margin', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .feature-one-left h2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'description_separator',
			[
				'label' => __( 'Description', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#536d87',
				'selectors' => [
					'{{WRAPPER}} .feature-one-left p' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_2,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description_typography',
				'selector' => '{{WRAPPER}} .feature-one-left p',
				'scheme' => Scheme_Typography::TYPOGRAPHY_2,
			]
		);

		$this->add_responsive_control(
			'description_padding',
			[
				'label' => __( 'Margin', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
				],
				'{{WRAPPER}} .feature-one-left p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			]
		);


		$this->add_control(
			'price_separator',
			[
				'label' => __( 'Price', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'price_color',
			[
				'label' => __( 'Price Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-amount .price, {{WRAPPER}} .pricing-amount .currency' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_2,
				],
			]
		);


		$this->add_control(
			'duration_color',
			[
				'label' => __( 'Subscription Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '#536d87',
				'selectors' => [
					'{{WRAPPER}} .pricing-amount .subscription' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        $this->add_inline_editing_attributes('title', 'basic');
        $this->add_inline_editing_attributes('description', 'basic');
        $this->add_inline_editing_attributes('price', 'basic');
        $this->add_inline_editing_attributes('currency_sign', 'basic');
        $this->add_inline_editing_attributes('duration', 'basic');

        ?>

		<div class="feature-one-left">
            <div class="pricing-amount feauter-amount">
                <sup><span class="currency" <?php echo $this->get_render_attribute_string( 'currency_sign' ); ?>><?php echo $settings['currency_sign']; ?></span></sup>
                <span class="price" <?php echo $this->get_render_attribute_string( 'price' ); ?>>
              		<?php echo $settings['price']; ?>
            	</span>
                <span class="subscription" <?php echo $this->get_render_attribute_string( 'duration' ); ?>>
	                <?php echo $settings['duration']; ?>
	            </span>
            </div>
            <h2 <?php echo $this->get_render_attribute_string( 'title' ); ?>><?php echo $settings['title']; ?></h2>
            <p <?php echo $this->get_render_attribute_string( 'description' ); ?>><?php echo $settings['description']; ?></p>
        </div>

        <?php
	}

}
