<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Map_Positions extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'map-positions';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Data Centers Map Positions', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'map_img',
			[
				'label' => __( 'Map Image', 'flake-ts' ),
				'type' => Controls_Manager::MEDIA,
			]
		);


		$this->add_control(
			'data_locations',
			[
				'label' => __( 'Data Locations', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'title',
						'label' => __( 'Title', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'address',
						'label' => __( 'Address', 'flake-ts' ),
						'type' => Controls_Manager::TEXTAREA,
					],
					[
						'name' => 'top',
						'label' => __( 'Top', 'flake-ts' ),
						'type' => Controls_Manager::NUMBER,
					],
					[
						'name' => 'right',
						'label' => __( 'Right', 'flake-ts' ),
						'type' => Controls_Manager::NUMBER,
					],
					[
						'name' => 'bottom',
						'label' => __( 'Bottom', 'flake-ts' ),
						'type' => Controls_Manager::NUMBER,
					],
					[
						'name' => 'left',
						'label' => __( 'Left', 'flake-ts' ),
						'type' => Controls_Manager::NUMBER,
					],
				],
				'default' => [
					[
						'name' => 'Jone Doe',
						'position' => 'Web Developer',
						'about' => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna',
						'social_links' => '<a href="#" target="_blank"><span class="ti-facebook"></span></a>',
					],

				],

			]
		);


		$this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment', 'flake-ts' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'flake-ts' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'flake-ts' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'flake-ts' ),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __( 'Justified', 'flake-ts' ),
						'icon' => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .the-map-image' => 'text-align: {{VALUE}};',
				],
			]
		);


		$this->add_responsive_control(
			'map_display',
			[
				'label' => __( 'Display', 'flake-ts' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => __('Choose Options', 'slake-ts'),
					'block' => __('Block', 'slake-ts'),
					'none' => __('None', 'slake-ts'),
					'initial' => __('Initial', 'slake-ts'),
				],
				'selectors' => [
					'{{WRAPPER}} .data-center-map' => 'display: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
			$settings = $this->get_settings();


			function grasmash_generate_css_properties($rules, $indent = 0) {
			  $css = '';
			  $prefix = str_repeat('  ', $indent);

			  foreach ($rules as $key => $value) {
			    if (is_array($value)) {
			      $selector = $key;
			      $properties = $value;

			      $css .= $prefix .grasmash_generate_css_properties($properties, $indent + 1);
			    }
			    else {
			      $property = $key;
				  if( $value ) {
					  $css .= $prefix . "$property: {$value}px;\n";
				  }
			    }
			  }
			  return $css;
			}


        ?>

		<div class="data-center-map">

			<div class="the-map-image">
				<img src="<?php echo $settings['map_img']['url']; ?>" alt="">
			</div>

			<?php

				$increment = 0.2;

				foreach($settings['data_locations'] as $location) :

				$increment += .2;

				$flat_css_rules = array(
				  '.location-single' => array(
				    'top' => $location['top'],
					'right' => $location['right'],
					'bottom' => $location['bottom'],
				    'left' => $location['left'],
				  ),
				);
			?>

				<div class="location-single" style="<?php echo grasmash_generate_css_properties($flat_css_rules); ?>">
					<div class="info-window">
						<h3><?php echo $location['title']; ?></h3>
						<?php echo $location['address']; ?>
					</div>

					<?php printf('
						<div class="map-icon wow zoomIn" data-wow-duration=".6s" data-wow-delay="%s"></div>',
						$increment . "s") ?>
				</div>

			<?php endforeach; ?>

        </div>
        <?php
	}

}
