<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Pricing_Table_Advanced extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'pricing-table-advanced';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pricing Table Advanced', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'tab_titles',
			[
				'label' => __( 'Tab Titles', 'slake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'annual_tab_title',
			[
				'label' => __( 'Annual Tab Title', 'slake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => 'Annual</span>',
			]
		);

		$this->add_control(
			'monthly_tab_title',
			[
				'label' => __( 'Monthly Tab Title', 'slake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => 'Monthly',
			]
		);

		$this->add_control(
			'table_layout',
			[
				'label' => __( 'Table Layout', 'slake-ts' ),
				'type' => Controls_Manager::SELECT,
				'options' => array(
					'col-md-12' => __('One Column', 'slake-ts'),
					'col-md-6' => __('Two Column', 'slake-ts'),
					'col-md-4' => __('Three Column', 'slake-ts'),
				),
				'default' => 'col-md-4'
			]
		);

		$this->add_control(
			'pricing_tables',
			[
				'label' => __( 'Pricing Tables', 'slake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'title',
						'label' => __( 'Title', 'slake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __('Professional', 'slake-ts')
					],
					[
						'name' => 'make_it_hightlight',
						'label' => __( 'Make it hightlight', 'slake-ts' ),
						'type' => Controls_Manager::SWITCHER,
						'label_on' => __( 'Show', 'slake-ts' ),
			    		'label_off' => __( 'No', 'slake-ts' ),
			            'separator'     => 'before'
					],
					[
						'name' => 'show_price_icon',
						'label' => __( 'Show Pricing Icon Image', 'slake-ts' ),
						'type' => Controls_Manager::SWITCHER,
						'label_on' => __( 'Show', 'slake-ts' ),
			    		'label_off' => __( 'No', 'slake-ts' ),
			            'separator'     => 'before',
						'default' => 'yes'
					],
					[
						'name' => 'price_icon_image',
						'label' => __( 'Pricing Icon Image', 'slake-ts' ),
						'type' => Controls_Manager::MEDIA,
						'condition' => [
							'show_price_icon' => 'yes'
						]
					],
					[
						'name' => 'highlight_text',
						'label' => __( 'Highlight Label Text', 'slake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __('Best Choice', 'slake-ts')
					],
					[
						'name' => 'currency',
						'label' => __( 'currency', 'slake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __('$', 'slake-ts')
					],
					[
						'name' => 'annual_price_label',
						'label' => __( 'Annual Price Text', 'slake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __('Annual', 'slake-ts')
					],
					[
						'name' => 'annual_price',
						'label' => __( 'Annual Price', 'slake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __('81', 'slake-ts')
					],
					[
						'name' => 'monthly_price_label',
						'label' => __( 'Monthly Price Text', 'slake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __('Monthly', 'slake-ts')
					],
					[
						'name' => 'monthly_price',
						'label' => __( 'Monthly Price', 'slake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __('9', 'slake-ts')
					],
					[
						'name' => 'pricing_info',
						'label' => __( 'Pricing Info', 'slake-ts' ),
						'type' => Controls_Manager::WYSIWYG,
					],
					[
						'name' => 'button_label',
						'label' => __( 'Button Label', 'slake-ts' ),
						'type' => Controls_Manager::TEXTAREA,
						'default' => __('Select Plan', 'slake-ts')
					],
					[
						'name' => 'button',
						'label' => __( 'Link', 'slake-ts' ),
						'type' => Controls_Manager::URL,
						'placeholder' => __( 'https://your-link.com', 'slake-ts' ),
						'show_external' => true,
						'default' => [
							'url' => '',
							'is_external' => true,
							'nofollow' => true,
						],
					],
					[
						'name' => 'use_icon',
						'label' => __( 'Use Icon', 'slake-ts' ),
						'type'    => Controls_Manager::SELECT,
						'options' => [
							'no' => __('No', 'slake-ts'),
							'yes' => __('Yes', 'slake-ts'),
						],
						'default' => 'no',
					],
					[
						'name' => 'icon',
						'label' => __( 'Icon', 'slake-ts' ),
						'type'    => Controls_Manager::ICON,
						'options' => slake_font_icons(),
						'condition' => [
							'use_icon' => 'yes'
						]
					],
					[
						'name' => 'icon_position',
						'label' => __( 'Icon Position', 'slake-ts' ),
						'type'    => Controls_Manager::SELECT,
						'options' => [
							'left' => __('Left', 'slake-ts'),
							'right' => __('Right', 'slake-ts'),
						],
						'default' => 'left',
						'condition' => [
							'use_icon' => 'yes'
						]
					],

				],
				'default' => [
					[
						'title' => __('Free', 'slake-ts'),
					],
					[
						'title' => __('Professional', 'slake-ts'),
					]
				],
			]
		);



		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment','flake-ts'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left','flake-ts'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center','flake-ts'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right','flake-ts'),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __( 'Justified','flake-ts'),
						'icon' => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-pricing-table' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'table_background',
				'label' => __( 'Background', 'flake-ts' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .single-pricing-table',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => __( 'Table Border', 'flake-ts' ),
				'selector' => '{{WRAPPER}} .single-pricing-table:hover, .single-pricing-table.active',
			]
		);

		$this->add_control(
			'title_separator',
			[
				'label' => __( 'Title','flake-ts'),
				'type' => Controls_Manager::HEADING,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single-pricing-table h2' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .single-pricing-table h2',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label' => __( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .single-pricing-table h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'price_separator',
			[
				'label' => __( 'Price','flake-ts'),
				'type' => Controls_Manager::HEADING,
			]
		);

		$this->add_control(
			'price_color',
			[
				'label' => __( 'Price Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-amount .price, {{WRAPPER}} .pricing-amount .currency' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_2,
				],
			]
		);


		$this->add_control(
			'duration_color',
			[
				'label' => __( 'Subscription Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-amount .subscription' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->add_control(
			'price_list_color',
			[
				'label' => __( 'Content Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-content ul li' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->add_control(
			'button_separator',
			[
				'label' => __( 'Button','flake-ts'),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __( 'Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '#fff',
				'selectors' => [
					'{{WRAPPER}} .pricing-content .pricing-btn' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_4,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'button_background',
				'label' => __( 'Background', 'flake-ts' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .pricing-content .pricing-btn',
			]
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .pricing-content .pricing-btn',
				'scheme' => Scheme_Typography::TYPOGRAPHY_4,
			]
		);

		$this->add_control(
			'button_hover_separator',
			[
				'label' => __( 'Button Hover','flake-ts'),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label' => __( 'Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '#fff',
				'selectors' => [
					'{{WRAPPER}} .pricing-content .pricing-btn:hover' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_4,
				],
			]
		);


		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'button_hover_background',
				'label' => __( 'Background', 'flake-ts' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .pricing-content .pricing-btn:hover',
			]
		);

		$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'button_hover_box_shadow',
					'label' => __( 'Box Shadow', 'flake-ts' ),
					'selector' => '{{WRAPPER}} .pricing-content .pricing-btn:hover',
				]
			);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        ?>

		<!-- section title row end -->
		<div class="row">
			<div class="col-md-12">
				<nav class="pricing-tab">

					<span class="monthly_tab_title">
						<?php echo $settings['monthly_tab_title']; ?>
					</span>
					<span class="pricing-tab-switcher"></span>
					<span class="annual_tab_title">
						<?php echo $settings['annual_tab_title']; ?>
					</span>

				</nav>
				<!-- section tab end -->
			</div>
		</div>
		<!-- section tab row end -->

		<div class="row advanced-pricing-table">

			<?php
				foreach( $settings['pricing_tables'] as $table ) :

					$text = $table['button_label'];

					$target = $table['button']['is_external'] ? ' target="_blank"' : '';
					$nofollow = $table['button']['nofollow'] ? ' rel="nofollow"' : '';

					if( $table['use_icon'] == 'yes' ) {

						$icon_text = '<i class="'. $table['icon'] .'"></i>';

						if( $table['icon_position'] == 'left' ) :
							$text = $icon_text . $text;
						else:
							$text = $text . $icon_text;
						endif;

					}

			?>
				<div class="<?php echo $settings['table_layout']; ?>">
					<div class="single-pricing-table <?php if( $table['make_it_hightlight'] == 'yes' ) echo 'active'; ?>">

						<?php if( $table['make_it_hightlight'] == 'yes' ) echo '<span class="table-highlight">'. $table['highlight_text'] .'</span>'; ?>

			            <h2><?php echo $table['title'] ?></h2>

				            <img src="<?php echo $table['price_icon_image']['url']; ?>" alt="<?php echo $table['title'] ?>">

			            <div class="pricing-amount">

							<div class="annual_price">
								<sup><span class="currency"><?php echo $table['currency'] ?></span></sup>
								<span class="price"> <?php echo $table['annual_price'] ?> </span>
								<span class="subscription"> <?php echo $table['annual_price_label'] ?> </span>
							</div>

							<div class="monthly_price">
								<sup><span class="currency"><?php echo $table['currency'] ?></span></sup>
								<span class="price"> <?php echo $table['monthly_price'] ?> </span>
								<span class="subscription"> <?php echo $table['monthly_price_label'] ?> </span>
							</div>

			            </div>

			            <div class="pricing-content">
			                <?php echo $table['pricing_info'] ?>

							<?php
								printf('<a href="%s" class="pricing-btn blue-btn" %s %s>%s</a>', $table['button']['url'], $target, $nofollow, $text);
							?>
			            </div>
			        </div>
				</div>

			<?php endforeach; ?>

	    </div>

        <?php
	}

}
