<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Pricing_Plan extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'pricing-plan';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pricing Plan', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'fist_box_title',
			[
				'label' => __( 'First Price Box Title', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'pricing_titles',
			[
				'label' => __( 'Pricing Labels', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'title',
						'label' => __( 'Title', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					]
				],

			]
		);



		$this->add_control(
			'pricing_plans',
			[
				'label' => __( 'Pricing Plans', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'title',
						'label' => __( 'Title', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'currency',
						'label' => __( 'Currency', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'price',
						'label' => __( 'Price', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'duration',
						'label' => __( 'Duration', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'price_lists',
						'label' => __( 'Lists', 'flake-ts' ),
						'type' => Controls_Manager::WYSIWYG,
					],
					[
						'name' => 'button_label',
						'label' => __( 'Button Label', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'url',
						'label' => __( 'URL', 'flake-ts' ),
						'type' => Controls_Manager::URL,
						'show_external' => true,
						'default' => [
							'url' => '#',
							'is_external' => true,
							'nofollow' => true,
						],
					]
				],

			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-hosting-price h2' => 'color: {{VALUE}};',
				],
			]
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label' => __( 'Title Typography', 'flake-ts' ),
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .single-hosting-price h2',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);


		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Accent Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .blue-btn' => 'background: {{VALUE}};',
					'{{WRAPPER}} .pricing-amount .price, {{WRAPPER}} .pricing-amount .currency' => 'color: {{VALUE}};'
				],
			]
		);

		$this->add_responsive_control(
			'first_section_margin_top',
			[
				'label' => __( 'First Box Margin Top', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-hosting-price.display-none' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'title_margin',
			[
				'label' => __( 'Title Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .single-hosting-price h2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
			$settings = $this->get_settings();

        ?>
			<div class="row">
				<div class="single-hosting-price display-none">
					<?php
						if( $settings['fist_box_title'] ) :
							echo '<h2>'. $settings['fist_box_title'] .'</h2>';
						endif;
					?>

					<ul>
						<?php foreach( $settings['pricing_titles'] as $pricings ) :  ?>
							<li><?php echo $pricings['title']; ?></li>
						<?php endforeach; ?>
					</ul>
				</div>
				<?php foreach( $settings['pricing_plans'] as $plans ) : ?>
					<div class="single-hosting-price">
						<h2><?php echo $plans['title']; ?></h2>

							<?php
								if( $plans['currency'] ) :
									echo '<div class="pricing-amount">';
									echo '<sup><span class="currency">'. $plans['currency'] .'</span></sup>';
								endif;

								if( $plans['price'] ) :
									echo '<span class="price">'. $plans['price'] .'</span>';
								endif;

								if( $plans['duration'] ) :
									echo '<span class="subscription">'. $plans['duration'] .'</span>';
									echo '</div>';
								endif;
							?>

						<?php echo $plans['price_lists']; ?>
						<?php
							$target = $plans['url']['is_external'] ? ' target="_blank"' : '';
							$nofollow = $plans['url']['nofollow'] ? ' rel="nofollow"' : '';

							if( $plans['button_label'] ) :
								printf('<a class="pricing-btn blue-btn" href="%s" %s %s>%s</a>', $plans['url']['url'], $target, $nofollow, $plans['button_label']);
							endif;
						?>
					</div>
				<?php endforeach; ?>

			</div>

        <?php
	}

}
