<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Pricing_Table extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'pricing-table';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pricing Table', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'make_active',
			[
				'label' => __( 'Highligh Table?', 'flake-ts' ),
				'type' => Controls_Manager::SWITCHER,
				'description' => __( 'Toggle to show this pricing table as highlighed', 'flake-ts' ),
				'label_on' => __( 'Show', 'flake-ts' ),
				'label_off' => __( 'Hide', 'flake-ts' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'title',
			[
				'label' => __( 'Title', 'flake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => 'Free',
			]
		);

		$this->add_control(
			'price',
			[
				'label' => __( 'Price', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => '19',
			]
		);

		$this->add_control(
			'currency_sign',
			[
				'label' => __( 'Currency Sign', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => '$',
			]
		);

		$this->add_control(
			'duration',
			[
				'label' => __( 'Subscribe Duration', 'flake-ts' ),
				'type' => Controls_Manager::TEXT,
				'default' => '/Annualy',
			]
		);

		$this->add_control(
			'pricing_plan',
			[
				'label' => __( 'Pricing Plan', 'flake-ts' ),
				'type' => Controls_Manager::WYSIWYG,
			]
		);

		$this->add_control(
			'show_price_icon',
			[
				'label' => __( 'Show Price Icon?', 'flake-ts' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'flake-ts' ),
				'label_off' => __( 'Hide', 'flake-ts' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'price_icon',
			[
				'label' => __( 'Price Icon', 'flake-ts' ),
				'type' => Controls_Manager::MEDIA,
				'condition' => [
					'show_price_icon' => 'yes'
				]
			]
		);


		$this->add_control(
			'pricing_button',
			[
				'label' => __( 'Pricing Button', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'button_title',
						'label' => __( 'Button Label', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __( 'Select Plan' , 'flake-ts' ),
						'label_block' => true,
					],
					[
						'name' => 'button_url',
						'label' => __( 'URL', 'flake-ts' ),
						'type' => Controls_Manager::URL,
						'show_label' => false,
					]
				],
				'default' => [
					[
						'button_title' => __( 'Select Plan', 'flake-ts' ),
					]

				],
			]
		);



		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label' => __( 'Alignment','flake-ts'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left','flake-ts'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center','flake-ts'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right','flake-ts'),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __( 'Justified','flake-ts'),
						'icon' => 'fa fa-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-pricing-table' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'table_background',
				'label' => __( 'Background', 'flake-ts' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .single-pricing-table',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => __( 'Table Border', 'flake-ts' ),
				'selector' => '{{WRAPPER}} .single-pricing-table:hover, .single-pricing-table.active',
			]
		);

		$this->add_control(
			'title_separator',
			[
				'label' => __( 'Title','flake-ts'),
				'type' => Controls_Manager::HEADING,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .single-pricing-table h2' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .single-pricing-table h2',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label' => __( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .single-pricing-table h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'price_separator',
			[
				'label' => __( 'Price','flake-ts'),
				'type' => Controls_Manager::HEADING,
			]
		);

		$this->add_control(
			'price_color',
			[
				'label' => __( 'Price Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-amount .price, {{WRAPPER}} .pricing-amount .currency' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_2,
				],
			]
		);


		$this->add_control(
			'duration_color',
			[
				'label' => __( 'Subscription Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-amount .subscription' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->add_control(
			'price_list_color',
			[
				'label' => __( 'Content Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-content ul li' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->add_control(
			'button_separator',
			[
				'label' => __( 'Button','flake-ts'),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'button_color',
			[
				'label' => __( 'Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pricing-content .pricing-btn' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_4,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'button_background',
				'label' => __( 'Background', 'flake-ts' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .pricing-content .pricing-btn',
			]
		);


		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'selector' => '{{WRAPPER}} .pricing-content .pricing-btn',
				'scheme' => Scheme_Typography::TYPOGRAPHY_4,
			]
		);

		$this->add_control(
			'button_hover_separator',
			[
				'label' => __( 'Button Hover','flake-ts'),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label' => __( 'Color','flake-ts'),
				'type' => Controls_Manager::COLOR,
				'default' => '#fff',
				'selectors' => [
					'{{WRAPPER}} .pricing-content .pricing-btn:hover' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_4,
				],
			]
		);


		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'button_hover_background',
				'label' => __( 'Background', 'flake-ts' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .pricing-content .pricing-btn:hover',
			]
		);

		$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'button_hover_box_shadow',
					'label' => __( 'Box Shadow', 'flake-ts' ),
					'selector' => '{{WRAPPER}} .pricing-content .pricing-btn:hover',
				]
			);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        $this->add_inline_editing_attributes('title', 'basic');
        $this->add_inline_editing_attributes('currency_sign', 'basic');
        $this->add_inline_editing_attributes('price', 'basic');
        $this->add_inline_editing_attributes('duration', 'basic');
        $this->add_inline_editing_attributes('pricing_plan', 'basic');

        ?>

			<div class="single-pricing-table <?php if( $settings['make_active'] == 'yes' ) echo 'active'; ?>">
	            <h2 <?php echo $this->get_render_attribute_string( 'title' ); ?>><?php echo $settings['title'] ?></h2>
				<?php if( $settings['show_price_icon'] == 'yes' ) : ?>
		            <img src="<?php echo $settings['price_icon']['url']; ?>" alt="pricing-icon">
				<?php endif; ?>
	            <div class="pricing-amount">
	                <sup><span class="currency" <?php echo $this->get_render_attribute_string( 'currency_sign' ); ?> ><?php echo $settings['currency_sign'] ?></span></sup>
	                <span class="price" <?php echo $this->get_render_attribute_string( 'price' ); ?>>
	                 <?php echo $settings['price'] ?>
	              	</span>
	                <span class="subscription" <?php echo $this->get_render_attribute_string( 'duration' ); ?>>
	                  <?php echo $settings['duration'] ?>
	              </span>
	            </div>
	            <div class="pricing-content" <?php echo $this->get_render_attribute_string( 'pricing_plan' ); ?>>
	                <?php echo $settings['pricing_plan'] ?>

					<?php
						if( $settings['pricing_button'] ) {
							foreach( $settings['pricing_button'] as $button ) {

								$target = $button['button_url']['is_external'] ? ' target="_blank"' : '';
								$nofollow = $button['button_url']['nofollow'] ? ' rel="nofollow"' : '';

								echo '<a class="pricing-btn blue-btn" href="'. $button['button_url']['url'] .'"'. $target . $nofollow .'>'. $button['button_title'] .'</a>';
							}
						}
					?>

	            </div>
	        </div>

        <?php
	}

}
