<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Image_With_Kit extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'slake-image';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Slake Image with Kit', 'slake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-hotspot';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'slake-ts' ),
			]
		);

		$this->add_control(
			'image',
			[
				'label' => __( 'Image', 'slake-ts' ),
                'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'alt_text',
			[
				'label' => __( 'Image Alt Text', 'slake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
			]
		);


		$this->add_control(
			'kit_image',
			[
				'label' => __( 'Image Kit', 'slake-ts' ),
                'type' => Controls_Manager::MEDIA,
				'dynamic' => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'kit_alt_text',
			[
				'label' => __( 'Kit Image Alt Text', 'slake-ts' ),
				'type' => Controls_Manager::TEXTAREA,
			]
		);

		$this->add_control(
            'element_animation_reveal',
            [
                'label'         => _x( 'Use Slake fade in animaion?', 'Section Control', 'slake-ts' ),
                'description'         => _x( 'Toggle this to use Slake fade in animation', 'Section Control', 'slake-ts' ),
				'type' => Controls_Manager::SWITCHER,
                'prefix_class'  => 'reveal-',
				'label_on' => __( 'Show', 'slake-ts' ),
				'label_off' => __( 'Hide', 'slake-ts' ),
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'slake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			'wrapper_separator',
			[
				'label' => __( 'Wrapper', 'slake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);


		$this->add_responsive_control(
			'wrapper_position',
			[
				'label' => __( 'Wrapper Position', 'flake-ts' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'absolute'  => __( 'Absolute', 'flake-ts' ),
					'relative' => __( 'Relative', 'flake-ts' ),
					'inherit' => __( 'Inherit', 'flake-ts' ),
					'initial' => __( 'Initial', 'flake-ts' ),
					'fixed' => __( 'Fixed', 'flake-ts' ),
					'scroll' => __( 'Scroll', 'flake-ts' ),
				],
				'selectors' => [
					'{{WRAPPER}} .cta-media' => 'position: {{VALUE}};',
				],
			]
		);

        $this->add_responsive_control(
			'wrapper_display',
			[
				'label' => __( 'Display', 'vapp-ts' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					''  => __( 'Choose Options', 'vapp-ts' ),
					'block'  => __( 'Block', 'vapp-ts' ),
					'inline_block' => __( 'Inline Block', 'vapp-ts' ),
					'none' => __( 'None', 'vapp-ts' ),
				],
				'selectors' => [
					'{{WRAPPER}} .cta-media' => 'display: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'wrapper_position_top',
			[
				'label' => __( 'Potition Top', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media' => 'top: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'wrapper_position_bottom',
			[
				'label' => __( 'Potition Bottom', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media' => 'bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'wrapper_position_left',
			[
				'label' => __( 'Potition Left', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media' => 'left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'wrapper_position_right',
			[
				'label' => __( 'Potition Right', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media' => 'right: {{SIZE}}{{UNIT}};',
				],
			]
		);



		$this->add_control(
			'main_image_separator',
			[
				'label' => __( 'Main Image', 'slake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);


		$this->add_responsive_control(
			'width',
			[
				'label' => __( 'Width', 'elementor' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'size_units' => [ '%', 'px', 'vw' ],
				'range' => [
					'%' => [
						'min' => 1,
						'max' => 100,
					],
					'px' => [
						'min' => 1,
						'max' => 1000,
					],
					'vw' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cta-media img.main-img' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'space',
			[
				'label' => __( 'Max Width', 'elementor' ) . ' (%)',
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'size_units' => [ '%' ],
				'range' => [
					'%' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cta-media img.main-img' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);


		$this->add_responsive_control(
			'img_display',
			[
				'label' => __( 'Display', 'flake-ts' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					''  => __( 'Choose options', 'flake-ts' ),
					'block'  => __( 'Block', 'flake-ts' ),
					'inline_block' => __( 'Inline Block', 'flake-ts' ),
					'none' => __( 'None', 'flake-ts' ),
				],
				'selectors' => [
					'{{WRAPPER}} .cta-media img.main-img' => 'display: {{VALUE}};',
				],
			]
		);



		$this->add_responsive_control(
			'img_position',
			[
				'label' => __( 'Image Position', 'flake-ts' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'absolute'  => __( 'Absolute', 'flake-ts' ),
					'relative' => __( 'Relative', 'flake-ts' ),
					'inherit' => __( 'Inherit', 'flake-ts' ),
					'initial' => __( 'Initial', 'flake-ts' ),
					'fixed' => __( 'Fixed', 'flake-ts' ),
					'scroll' => __( 'Scroll', 'flake-ts' ),
				],
				'selectors' => [
					'{{WRAPPER}} .cta-media img.main-img' => 'position: {{VALUE}};',
				],
			]
		);


		$this->add_responsive_control(
			'img_position_top',
			[
				'label' => __( 'Potition Top', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.main-img' => 'top: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'img_position_bottom',
			[
				'label' => __( 'Potition Bottom', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.main-img' => 'bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'img_position_left',
			[
				'label' => __( 'Potition Left', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.main-img' => 'left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'img_position_right',
			[
				'label' => __( 'Potition Right', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.main-img' => 'right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'img_z_index',
			[
				'label' => __( 'Z Index', 'flake-ts' ),
				'type' => Controls_Manager::NUMBER,
				'selectors' => [
					'{{WRAPPER}} .cta-media img.main-img' => 'z-index: {{VALUE}};',
				],
			]
		);


		$this->add_responsive_control(
			'img_opacity',
			[
				'label' => __( 'Opacity', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.01,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.main-img' => 'opacity: {{SIZE}};',
				],
			]
		);


		$this->add_control(
			'kit_image_separator',
			[
				'label' => __( 'Image Kit', 'slake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);


		$this->add_responsive_control(
			'kit_img_width',
			[
				'label' => __( 'Width', 'elementor' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'size_units' => [ '%', 'px', 'vw' ],
				'range' => [
					'%' => [
						'min' => 1,
						'max' => 100,
					],
					'px' => [
						'min' => 1,
						'max' => 1000,
					],
					'vw' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cta-media img.kit-img' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'kit_img_max_width',
			[
				'label' => __( 'Max Width', 'elementor' ) . ' (%)',
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'size_units' => [ '%' ],
				'range' => [
					'%' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .cta-media img.kit-img' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);


		$this->add_responsive_control(
			'kit_img_display',
			[
				'label' => __( 'Display', 'flake-ts' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
                    ''  => __( 'Choose options', 'flake-ts' ),
					'block'  => __( 'Block', 'flake-ts' ),
					'inline_block' => __( 'Inline Block', 'flake-ts' ),
					'none' => __( 'None', 'flake-ts' ),
				],
				'selectors' => [
					'{{WRAPPER}} .cta-media img.kit-img' => 'display: {{VALUE}};',
				],
			]
		);



		$this->add_responsive_control(
			'kit_img_position',
			[
				'label' => __( 'Image Position', 'flake-ts' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'absolute'  => __( 'Absolute', 'flake-ts' ),
					'relative' => __( 'Relative', 'flake-ts' ),
					'inherit' => __( 'Inherit', 'flake-ts' ),
					'initial' => __( 'Initial', 'flake-ts' ),
					'fixed' => __( 'Fixed', 'flake-ts' ),
					'scroll' => __( 'Scroll', 'flake-ts' ),
				],
				'selectors' => [
					'{{WRAPPER}} .cta-media img.kit-img' => 'position: {{VALUE}};',
				],
			]
		);


		$this->add_responsive_control(
			'kit_img_position_top',
			[
				'label' => __( 'Potition Top', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.kit-img' => 'top: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'kit_img_position_bottom',
			[
				'label' => __( 'Potition Bottom', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.kit-img' => 'bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'kit_img_position_left',
			[
				'label' => __( 'Potition Left', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.kit-img' => 'left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'kit_img_position_right',
			[
				'label' => __( 'Potition Right', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 2,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.kit-img' => 'right: {{SIZE}}{{UNIT}};',
				],
			]
		);



		$this->add_responsive_control(
			'kit_img_z_index',
			[
				'label' => __( 'Z Index', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.kit-img' => 'z-index: {{SIZE}};',
				],
			]
		);


		$this->add_responsive_control(
			'kit_img_opacity',
			[
				'label' => __( 'Opacity', 'flake-ts' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.01,
					],
				],

				'selectors' => [
					'{{WRAPPER}} .cta-media img.kit-img' => 'opacity: {{SIZE}};',
				],
			]
		);


		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

        $this->add_inline_editing_attributes('title', 'basic');
        $this->add_inline_editing_attributes('description', 'basic');

        ?>

			<div class="cta-media">
	            <img src="<?php echo $settings['image']['url']; ?>" alt="<?php echo $settings['alt_text']; ?>" class="main-img" data-wow-duration=".8s">

				<?php
					if( $settings['kit_image']['url'] ) :
						echo '<img src="'. $settings['kit_image']['url'] .'"  alt="'. $settings['kit_alt_text'] .'" class="kit-img wow slakeFadeInDown" data-wow-duration="2s" data-wow-delay=".1s">';
					endif;
				?>
	        </div>
	        <!-- media content end -->

        <?php
	}

}
