<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Team_Slider extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'team-slider';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Team Slider', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);

		$this->add_control(
			'team_slides',
			[
				'label' => __( 'Team Slides', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'name',
						'label' => __( 'Name', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'position',
						'label' => __( 'Position', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'about',
						'label' => __( 'About', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
					],
					[
						'name' => 'picture',
						'label' => __( 'Picture', 'flake-ts' ),
						'type' => Controls_Manager::MEDIA,
					],
					[
						'name' => 'social_links',
						'label' => __( 'Social Links', 'flake-ts' ),
						'type' => Controls_Manager::TEXTAREA,
						'description' => __( 'Use themify or font awesome icons family', 'flake-ts' ),
					],
				],
				'default' => [
					[
						'name' => 'Jone Doe',
						'position' => 'Web Developer',
						'about' => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna',
						'social_links' => '<a href="#" target="_blank"><span class="ti-facebook"></span></a>',
					],

				],

			]
		);



		$this->add_control(
			'slider_options_rtl',
			[
				'label' => __( 'Slider RTL?', 'elementor' ),
				'type' => Controls_Manager::SELECT,
				'options' => array(
					'true' => 'Yes',
					'false' => 'No',
				),
				'default' => 'false',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .social-links span' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);

		$this->add_control(
			'icon_bg_color',
			[
				'label' => __( 'Icon Background Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .social-links span' => 'background: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_2,
				],
			]
		);

		$this->add_control(
			'icon_hover_color',
			[
				'label' => __( 'Icon Hover Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .social-links span:hover' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_3,
				],
			]
		);

		$this->add_control(
			'icon_hover_bg_color',
			[
				'label' => __( 'Icon Hover Background Color', 'elementor' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .social-links span:hover' => 'background: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_4,
				],
			]
		);



		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
			$settings = $this->get_settings();


			$rtl_mode = $settings['slider_options_rtl'] == 'true' ? true : false;

			$slider_options = array(
				'rtl' => $rtl_mode
			);

			$slider_options = json_encode( $slider_options );
        ?>

			<div class="team-carosuel" data-options='<?php echo $slider_options ?>'>

				<?php
					foreach( $settings['team_slides']  as $team_member ) :
				?>

		            <div class="team-carosule-single-item">
						<div class="member-image">
							<img src="<?php echo $team_member['picture']['url']; ?>" alt="<?php echo $team_member['name']; ?>">
						</div>
		                <div class="team-meta">
		                    <h4><?php echo $team_member['name']; ?></h4>
		                    <p><?php echo $team_member['position']; ?></p>
		                </div>
		                <div class="team-overlay">
		                    <h5><?php echo $team_member['name']; ?></h5>
		                    <p class="meta-p"><?php echo $team_member['position']; ?></p>
		                    <p><?php echo $team_member['about']; ?></p>
		                    <div class="team-social-links">
		                        <div class="team-member-social-links">
		                            <?php echo $team_member['social_links']; ?>
		                        </div>
		                    </div>
		                </div>
		            </div>

				<?php
					endforeach;
				?>

	        </div>

        <?php
	}

}
