<?php
namespace SlakeTS\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Testimonials_Block extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'testimonial-block';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Testimonials Block', 'flake-ts' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	 public function get_categories() {
 	    return [ 'slake-addons' ];
 	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'flake-ts' ),
			]
		);


		$this->add_control(
			'testimonials_slider',
			[
				'label' => __( 'Testimonials', 'flake-ts' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'title',
						'label' => __( 'Name', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
						'default' => __( 'Michael Clarke' , 'flake-ts' ),
						'label_block' => true,
					],
					[
						'name' => 'description',
						'label' => __( 'Description', 'flake-ts' ),
						'type' => Controls_Manager::TEXTAREA,
						'show_label' => false,
					],
					[
						'name' => 'image',
						'label' => __( 'Image', 'flake-ts' ),
						'type' => Controls_Manager::MEDIA,
						'show_label' => false,
					],
					[
						'name' => 'designation',
						'label' => __( 'Designation', 'flake-ts' ),
						'type' => Controls_Manager::TEXT,
						'show_label' => false,
						'default' => 'Co Founder'
					],
					[
						'name' => 'star',
						'label' => __( 'Star', 'flake-ts' ),
						'type' => Controls_Manager::SELECT,
						'options' => array(
							'1' => '1 Star',
							'2' => '2 Star',
							'3' => '3 Star',
							'4' => '4 Star',
							'5' => '5 Star'
						)
					]
				],
				'default' => [
					[
						'title' => __( 'Michael Clarke', 'flake-ts' ),
						'description' => __( 'Lorem ipsum dolor sittem ametam ngcing elit, per sed teimpor inunt ut sedig do eiusmod.', 'flake-ts' ),
						'url' => __( 'Lead Developer', 'flake-ts' ),

					],
					[
						'title' => __( 'Jonathon Best', 'flake-ts' ),
						'description' => __( 'Lorem ipsum dolor sittem ametam ngcing elit, per sed teimpor inunt ut sedig do eiusmod.', 'flake-ts' ),
						'url' => __( 'System Engineer', 'flake-ts' ),
					]

				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => __( 'Content', 'flake-ts' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __( 'Box Shadow', 'flake-ts' ),
				'selector' => '{{WRAPPER}} .testi-carousel .testi-single-item .item-inner',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'hover:box_shadow',
				'label' => __( 'Box Shadow on hover', 'flake-ts' ),
				'selector' => '{{WRAPPER}} .testi-carousel .testi-single-item .item-inner:hover',
			]
		);

		$this->add_control(
			'title_separator',
			[
				'label' => __( 'Name', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial-meta h4' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .testimonial-meta h4',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label' => __( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .testimonial-meta h4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'description_separator',
			[
				'label' => __( 'Description', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testi-single-item .item-inner p' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'description_typography',
				'selector' => '{{WRAPPER}} .testi-single-item .item-inner p',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'description_padding',
			[
				'label' => __( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .testi-single-item .item-inner p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'url_separator',
			[
				'label' => __( 'URl', 'flake-ts' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'url_color',
			[
				'label' => __( 'Color', 'flake-ts' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .item-inner .testimonial-meta p' => 'color: {{VALUE}};',
				],
				'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'url_typography',
				'selector' => '{{WRAPPER}} .item-inner .testimonial-meta p',
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->add_responsive_control(
			'url_padding',
			[
				'label' => __( 'Padding', 'flake-ts' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .item-inner .testimonial-meta p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();


        ?>

		<div class="testimonials-list clearfix">
			<?php
				if( count( $settings['testimonials_slider'] ) > 0 ) :
					foreach( $settings['testimonials_slider'] as $slider ) :
			?>
		        <div class="single-item">
		            <div class="item-inner">

						<?php printf('<img src="%s" alt="testimonial quote" class="quote-img">', get_template_directory_uri() . '/assets/img/quote-shape.png'); ?>

						<p class="review"><?php echo $slider['description']; ?></p>

						<div class="author-meta">
							<div class="author-left">
								<img src="<?php echo $slider['image']['url']; ?>" alt="<?php echo $slider['title']; ?>">

								<div class="author-info">
									<h4><?php echo $slider['title']; ?></h4>
									<p><?php echo $slider['designation']; ?></p>
								</div>

							</div>
							<div class="author-right">
								<?php
									for($i=1;$i <= $slider['star']; $i++ ) :
										echo '<i class="fa fa-star"></i>';
									endfor;
								?>
							</div>
						</div>

		            </div>
		        </div>
			<?php
					endforeach;
				endif;
			?>
	    </div>

        <?php
	}

}
